//
// Decompiled with: Decompiler.NET, Version=2.0.0.230, Culture=neutral, PublicKeyToken=null, Version: 2.0.0.230
// Decompilation Started at: 14/02/2008 11:22:16
// Copyright 2003 - 2004, Jungle Creatures, Inc., All Rights Reserved. http://www.junglecreatures.com/
// Written by Jonathan Pierce, Email: support@junglecreatures.com
//

namespace LanmarkControls.LECHardwareAbstraction.FPGAInterface

{
		
		#region Namespace Import Declarations
		
			using LanmarkControls.CommonLib.Extension;
			using LanmarkControls.CommonLib.General;
			using LanmarkControls.CommonLib.Protocol;
			using LanmarkControls.LECHardwareAbstraction;
			using LanmarkControls.LECHardwareAbstraction.PInvoke;
			using OpenNETCF.Win32;
			using System.IO;
			using System;
			using System.Runtime.InteropServices;
			using System.Text;
			using System.Threading;
			
		#endregion
		
	internal class FPGA
	
	{
		
		#region Fields
			private byte interlockEnabledCache;
			private byte interlockPolarityCache;
			private bool m_bAbort;
			private bool m_bSendingData;
			private int m_iMECConnection;
			private readonly int m_iNamedEventSize;
			private int m_iSendingDataTimestamp;
			private string m_strMessageLog;
			private uint m_uiSegmentBits;
			private uint m_uiSegmentNumber;
			private uint m_uiSegmentSize;
		#endregion
		
		#region Nested Types
		
			private enum MecFPGACmdProcState
			
			{
				MecCmdState_ILLEGAL = -1, 
				MecCmdState_DISABLE = 0, 
				MecCmdState_ENABLE = 1, 
				MecCmdState_LAST = 2, 
			}
			
			
			private enum MecFPGAMsgQueue
			
			{
				MecMsgQueue_ILLEGAL = -1, 
				MecMsgQueue_DISABLE = 0, 
				MecMsgQueue_ENABLE = 1, 
				MecMsgQueue_LAST = 2, 
			}
			
			
			private class MecFPGAStatus
			
			{
				
				#region Fields
					public const int MecStateAborting = 1024;
					public const int MecStateActive = 2;
					public const int MecStateBufferFull = 512;
					public const int MecStateCmdEnable = 256;
					public const int MecStateDeinit = 3;
					public const int MecStateIdle = 1;
					public const int MecStateInit = 0;
					public const int MecStateMask = 255;
					public const int MecStatePaused = 2048;
				#endregion
				
				#region Constructors
				
					public MecFPGAStatus ()
					
					{
					}
					
				#endregion
			}
			
			
			private enum MecFPGAWdogTime
			
			{
				MecFPGAWdogTime_ILLEGAL = -1, 
				MecFPGAWdogTime_DISABLE = 0, 
				MecFPGAWdogTime_90_US = 1, 
				MecFPGAWdogTime_9_MS = 2, 
				MecFPGAWdogTime_3_S = 3, 
				MecFPGAWdogTime_9_S = 4, 
				MecFPGAWdogTime_30_S = 5, 
				MecFPGAWdogTime_LAST = 6, 
			}
			
			
			private enum Win32Errors
			
			{
				NotReady = 21, 
				InvalidParameter = 87, 
				NoMoreItems = 259, 
			}
			
		#endregion
		
		#region Constructors
		
			public FPGA ()
			
			{
				this.m_iNamedEventSize = 260;
				this.m_uiSegmentSize = uint.MinValue;
				this.m_uiSegmentNumber = uint.MinValue;
				this.m_uiSegmentBits = uint.MinValue;
				this.m_strMessageLog = "FPGA - No message available.";
				this.interlockPolarityCache = byte.MinValue;
				this.interlockEnabledCache = byte.MinValue;
				this.m_iMECConnection = -1;
				this.m_bAbort = false;
				this.m_bSendingData = false;
				this.m_iSendingDataTimestamp = 0;
			}
			
		#endregion
		
		#region Properties
		
			public virtual bool Abort
			
			{
				get
				{
					return this.m_bAbort;
				}
				set
				{
					this.m_bAbort = value;
				}
			}
			
			
			public bool CommandProcessingEnabled
			
			{
				get
				{
					MecStatus mecStatus1 = this.DriverStatus;
					if (mecStatus1 == null)
					{
						return false;
					}
					else
					{
						return ((mecStatus1.DriverStatus & 256) > 0);
					}
				}
			}
			
			
			public bool CommandProcessingFull
			
			{
				get
				{
					MecStatus mecStatus1 = this.DriverStatus;
					if (mecStatus1 == null)
					{
						return false;
					}
					else
					{
						return ((mecStatus1.DriverStatus & 512) > 0);
					}
				}
			}
			
			
			public bool CommandProcessingPaused
			
			{
				get
				{
					MecStatus mecStatus1 = this.DriverStatus;
					if (mecStatus1 == null)
					{
						return false;
					}
					else
					{
						return ((mecStatus1.DriverStatus & 2048) > 0);
					}
				}
			}
			
			
			private MecStatus DriverStatus
			
			{
				get
				{
					int i2;
					if (this.MECConnection == -1)
					{
						this.m_strMessageLog = "FPGA.DriverStatus - Connect was not called.";
						return null;
					}
					byte[] byteArray1 = new byte[4];
					byte[] byteArray2 = new byte[28];
					int i1 = 0;
					if (! DeviceDriver.DeviceIoControl (this.MECConnection, this.IOCTL_MEC_GET_DRIVER_STATUS, byteArray1, 0, byteArray2, byteArray2.Length, ref i1, 0))
					{
						i2 = Marshal.GetLastWin32Error ();
						this.m_strMessageLog = string.Format ("FPGA.DriverStatus - IOCTL_MEC_GET_DRIVER_STATUS error 0x03d {0}.", i2);
						return null;
					}
					MecStatus mecStatus1 = new MecStatus (byteArray2);
					string string1 = "";
					int i3 = (mecStatus1.DriverStatus & 255);
					switch (i3)
					{
						case 0:
						
						{
								string1 = (string1 + "Initialized");
								break;
						}
						case 1:
						
						{
								string1 = (string1 + "Idle");
								break;
						}
						case 2:
						
						{
								string1 = (string1 + "Active");
								break;
						}
						case 3:
						
						{
								string1 = (string1 + "Deinitialized");
								break;
						}
					}
					string1 = (string1 + (((mecStatus1.DriverStatus & 256) > 0) ? ",CmdEnable" : ",CmdDisable"));
					string1 = (string1 + (((mecStatus1.DriverStatus & 512) > 0) ? ",Full" : ",NotFull"));
					string1 = (string1 + (((mecStatus1.DriverStatus & 1024) > 0) ? ",Aborting" : ",Running"));
					string1 = (string1 + (((mecStatus1.DriverStatus & 2048) > 0) ? ",Paused" : ",Resumed"));
					this.m_strMessageLog = ("FPGA.DriverStatus - Success 0x03d " + string1 + ".");
					return mecStatus1;
				}
			}
			
			
			public int IOCTL_MEC_GET_BUF_POOL_PARAMS
			
			{
				get
				{
					return DeviceDriver.CTL_CODE (21, 2050, 0, 0);
				}
			}
			
			
			public int IOCTL_MEC_GET_BUF_POOL_SEGMENT
			
			{
				get
				{
					return DeviceDriver.CTL_CODE (21, 2051, 0, 0);
				}
			}
			
			
			public int IOCTL_MEC_GET_DRIVER_STATUS
			
			{
				get
				{
					return DeviceDriver.CTL_CODE (21, 2052, 0, 0);
				}
			}
			
			
			public int IOCTL_MEC_GET_EXCPT_MSG
			
			{
				get
				{
					return DeviceDriver.CTL_CODE (21, 2063, 0, 0);
				}
			}
			
			
			public int IOCTL_MEC_GET_FPGA_MSG
			
			{
				get
				{
					return DeviceDriver.CTL_CODE (21, 2057, 0, 0);
				}
			}
			
			
			public int IOCTL_MEC_GET_MSG_EVENT_ID
			
			{
				get
				{
					return DeviceDriver.CTL_CODE (21, 2056, 0, 0);
				}
			}
			
			
			public int IOCTL_MEC_GET_REGISTER
			
			{
				get
				{
					return DeviceDriver.CTL_CODE (21, 2053, 0, 0);
				}
			}
			
			
			public int IOCTL_MEC_INTERLOCK_CONFIG
			
			{
				get
				{
					return DeviceDriver.CTL_CODE (21, 2064, 0, 0);
				}
			}
			
			
			public int IOCTL_MEC_INTERLOCK_ENABLE
			
			{
				get
				{
					return DeviceDriver.CTL_CODE (21, 2065, 0, 0);
				}
			}
			
			
			public int IOCTL_MEC_OP_ABORT
			
			{
				get
				{
					return DeviceDriver.CTL_CODE (21, 2066, 0, 0);
				}
			}
			
			
			public int IOCTL_MEC_OP_BITSTREAM_LOAD
			
			{
				get
				{
					return DeviceDriver.CTL_CODE (21, 2049, 0, 0);
				}
			}
			
			
			public int IOCTL_MEC_OP_BUFFER_FLUSH
			
			{
				get
				{
					return DeviceDriver.CTL_CODE (21, 2055, 0, 0);
				}
			}
			
			
			public int IOCTL_MEC_OP_EXCPT_MSG_QUEUE_FLUSH
			
			{
				get
				{
					return DeviceDriver.CTL_CODE (21, 2062, 0, 0);
				}
			}
			
			
			public int IOCTL_MEC_OP_FPGA_MSG_QUEUE_FLUSH
			
			{
				get
				{
					return DeviceDriver.CTL_CODE (21, 2061, 0, 0);
				}
			}
			
			
			public int IOCTL_MEC_OP_MSG_QUEUE_ENABLE
			
			{
				get
				{
					return DeviceDriver.CTL_CODE (21, 2068, 0, 0);
				}
			}
			
			
			public int IOCTL_MEC_OP_PAUSE
			
			{
				get
				{
					return DeviceDriver.CTL_CODE (21, 2069, 0, 0);
				}
			}
			
			
			public int IOCTL_MEC_OP_RESUME
			
			{
				get
				{
					return DeviceDriver.CTL_CODE (21, 2070, 0, 0);
				}
			}
			
			
			public int IOCTL_MEC_OP_SOFT_RESET
			
			{
				get
				{
					return DeviceDriver.CTL_CODE (21, 2048, 0, 0);
				}
			}
			
			
			public int IOCTL_MEC_SET_CMD_PROC_STATE
			
			{
				get
				{
					return DeviceDriver.CTL_CODE (21, 2059, 0, 0);
				}
			}
			
			
			public int IOCTL_MEC_SET_FIFO_DATA
			
			{
				get
				{
					return DeviceDriver.CTL_CODE (21, 2067, 0, 0);
				}
			}
			
			
			public int IOCTL_MEC_SET_FPGA_MSG
			
			{
				get
				{
					return DeviceDriver.CTL_CODE (21, 2058, 0, 0);
				}
			}
			
			
			public int IOCTL_MEC_SET_REGISTER
			
			{
				get
				{
					return DeviceDriver.CTL_CODE (21, 2054, 0, 0);
				}
			}
			
			
			public int IOCTL_MEC_SET_WDOG_TIME
			
			{
				get
				{
					return DeviceDriver.CTL_CODE (21, 2060, 0, 0);
				}
			}
			
			
			public virtual int MECConnection
			
			{
				get
				{
					return this.m_iMECConnection;
				}
				set
				{
					this.m_iMECConnection = value;
				}
			}
			
			
			public string MessageLog
			
			{
				get
				{
					return this.m_strMessageLog;
				}
			}
			
			
			public virtual int MsgQueueSize
			
			{
				get
				{
					int i2;
					if (this.MECConnection == -1)
					{
						this.m_strMessageLog = "FPGA.MsgQueueSize - Connect was not called.";
						return 0;
					}
					byte[] byteArray1 = new byte[4];
					byte[] byteArray2 = new byte[28];
					int i1 = 0;
					if (! DeviceDriver.DeviceIoControl (this.MECConnection, this.IOCTL_MEC_GET_DRIVER_STATUS, byteArray1, 0, byteArray2, byteArray2.Length, ref i1, 0))
					{
						i2 = Marshal.GetLastWin32Error ();
						this.m_strMessageLog = string.Format ("FPGA.MsgQueueSize - IOCTL_MEC_GET_DRIVER_STATUS error 0x03d {0}.", i2);
						return 0;
					}
					MecStatus mecStatus1 = new MecStatus (byteArray2);
					this.m_strMessageLog = string.Format ("FPGA.MsgQueueSize - size 0x03d {0}.", mecStatus1.MessagesInQueue);
					return mecStatus1.MessagesInQueue;
				}
			}
			
			
			public uint SegmentBits
			
			{
				get
				{
					if (this.m_uiSegmentBits == uint.MinValue)
					{
						this.m_uiSegmentBits = ((uint) (((int) Convert.ToUInt32 (Math.Pow (2D, ((double) this.SegmentNumber)))) - 1));
					}
					return this.m_uiSegmentBits;
				}
			}
			
			
			public uint SegmentNumber
			
			{
				get
				{
					if (this.m_uiSegmentNumber != uint.MinValue)
					{
						return this.m_uiSegmentNumber;
					}
					RegistryKeyReader registryKeyReader1 = new RegistryKeyReader ();
					this.m_uiSegmentNumber = registryKeyReader1.GetDWORDValue (Registry.LocalMachine, "\\Drivers\\BuiltIn\\FPGA", "BufferSegments");
					return this.m_uiSegmentNumber;
				}
			}
			
			
			public uint SegmentSize
			
			{
				get
				{
					if (this.m_uiSegmentSize != uint.MinValue)
					{
						return this.m_uiSegmentSize;
					}
					RegistryKeyReader registryKeyReader1 = new RegistryKeyReader ();
					this.m_uiSegmentSize = registryKeyReader1.GetDWORDValue (Registry.LocalMachine, "\\Drivers\\BuiltIn\\FPGA", "SegmentSize");
					return this.m_uiSegmentSize;
				}
			}
			
			
			public virtual bool SendingData
			
			{
				get
				{
					return this.m_bSendingData;
				}
				set
				{
					this.m_bSendingData = value;
				}
			}
			
			
			public int SendingDataTimestamp
			
			{
				get
				{
					return this.m_iSendingDataTimestamp;
				}
				set
				{
					this.m_iSendingDataTimestamp = value;
				}
			}
			
			
			public string Version
			
			{
				get
				{
					int i2;
					if (this.MECConnection == -1)
					{
						this.m_strMessageLog = "FPGA.Version - Connect was not called.";
						return null;
					}
					byte[] byteArray1 = new byte[4];
					byte[] byteArray2 = new byte[28];
					int i1 = 0;
					if (! DeviceDriver.DeviceIoControl (this.MECConnection, this.IOCTL_MEC_GET_DRIVER_STATUS, byteArray1, 0, byteArray2, byteArray2.Length, ref i1, 0))
					{
						i2 = Marshal.GetLastWin32Error ();
						this.m_strMessageLog = string.Format ("FPGA.Version - IOCTL_MEC_GET_DRIVER_STATUS error 0x03d {0}.", i2);
						return "";
					}
					MecStatus mecStatus1 = new MecStatus (byteArray2);
					this.m_strMessageLog = ("FPGA.Version - Success 0x03d " + mecStatus1.FPGARevision.ToString () + ".");
					return mecStatus1.FPGARevision.ToString ();
				}
			}
			
		#endregion
		
		#region Methods
		
			internal uint CalcQualifiedInterlocks (uint uiInterlockBits)
			
			{
				return ((uint) (this.interlockEnabledCache & (this.interlockPolarityCache ^ uiInterlockBits)));
			}
			
			public bool ClearExceptMessageQueue ()
			
			{
				int i1 = 0;
				if (this.MECConnection == -1)
				{
					this.m_strMessageLog = "FPGA.ClearExceptMessageQueue() - Connect was not called.";
					return false;
				}
				byte[] byteArray1 = new byte[4];
				byte[] byteArray2 = new byte[4];
				int i2 = 0;
				if (! DeviceDriver.DeviceIoControl (this.MECConnection, this.IOCTL_MEC_OP_EXCPT_MSG_QUEUE_FLUSH, byteArray1, 0, byteArray2, 0, ref i2, 0))
				{
					i1 = Marshal.GetLastWin32Error ();
					this.m_strMessageLog = string.Format ("FPGA.ClearExceptMessageQueue() - IOCTL_MEC_OP_EXCPT_MSG_QUEUE_FLUSH error 0x03d {0}.", i1);
					return false;
				}
				else
				{
					this.m_strMessageLog = "FPGA.ClearExceptMessageQueue() - Success.";
					return true;
				}
			}
			
			public bool ClearMessageQueue ()
			
			{
				int i1 = 0;
				if (this.MECConnection == -1)
				{
					this.m_strMessageLog = "FPGA.ClearMessageQueue() - Connect was not called.";
					return false;
				}
				byte[] byteArray1 = new byte[4];
				byte[] byteArray2 = new byte[4];
				int i2 = 0;
				if (! DeviceDriver.DeviceIoControl (this.MECConnection, this.IOCTL_MEC_OP_FPGA_MSG_QUEUE_FLUSH, byteArray1, 0, byteArray2, 0, ref i2, 0))
				{
					i1 = Marshal.GetLastWin32Error ();
					this.m_strMessageLog = string.Format ("FPGA.ClearMessageQueue() - IOCTL_MEC_OP_FPGA_MSG_QUEUE_FLUSH error 0x03d {0}.", i1);
					return false;
				}
				else
				{
					this.m_strMessageLog = "FPGA.ClearMessageQueue() - Success.";
					return true;
				}
			}
			
			public bool Connect ()
			
			{
				if (this.MECConnection != -1)
				{
					this.m_strMessageLog = "FPGA.Connect() - Already connected. Return true.";
					return true;
				}
				else
				{
					this.MECConnection = DeviceDriver.CreateFile ("MEC1:", -1073741824, 3, IntPtr.Zero, 3, 128, 0);
					if (this.MECConnection == -1)
					{
						this.m_strMessageLog = ("FPGA.Connect() - Connection failed 0x03d " + Marshal.GetLastWin32Error ().ToString ());
						return false;
					}
					else
					{
						this.m_strMessageLog = "FPGA.Connect() - Success.";
						return true;
					}
				}
			}
			
			public bool Connected ()
			
			{
				return (this.MECConnection != -1);
			}
			
			public bool Disconnect ()
			
			{
				if (this.MECConnection == -1)
				{
					this.m_strMessageLog = "FPGA.Disconnect() - Already disconnected. Return true.";
					return true;
				}
				else
				{
					bool b1 = DeviceDriver.CloseHandle (this.MECConnection);
					this.MECConnection = -1;
					this.m_strMessageLog = "FPGA.Disconnect() - Success.";
					return true;
				}
			}
			
			public bool EnableMsgQueue (bool pbEnable)
			
			{
				if (this.MECConnection == -1)
				{
					return false;
				}
				byte[] byteArray1 = BitConverter.GetBytes ((pbEnable ? 1 : 0));
				byte[] byteArray2 = new byte[4];
				int i1 = 0;
				if (DeviceDriver.DeviceIoControl (this.MECConnection, this.IOCTL_MEC_OP_MSG_QUEUE_ENABLE, byteArray1, byteArray1.Length, byteArray2, 0, ref i1, 0))
				{
					return true;
				}
				else
				{
					int i2 = Marshal.GetLastWin32Error ();
					return false;
				}
			}
			
			public string EventName (LECHAL.MecFPGAEvent penumEventName)
			
			{
				if (this.MECConnection == -1)
				{
					return "";
				}
				byte[] byteArray1 = new byte[this.m_iNamedEventSize];
				int i1 = 0;
				byte[] byteArray2 = BitConverter.GetBytes (((int) penumEventName));
				if (! DeviceDriver.DeviceIoControl (this.MECConnection, this.IOCTL_MEC_GET_MSG_EVENT_ID, byteArray2, byteArray2.Length, byteArray1, byteArray1.Length, ref i1, 0))
				{
					int i3 = Marshal.GetLastWin32Error ();
					return "";
				}
				int i2 = ArrayEx.ValueLength (byteArray1, 0, byteArray1.Length);
				if (i2 != 0)
				{
					return Encoding.Unicode.GetString (byteArray1, 0, i2);
				}
				else
				{
					return "";
				}
			}
			
			internal MecRegisters GetAllRegisters ()
			
			{
				int i2;
				int i3;
				int i4;
				if (this.MECConnection == -1)
				{
					this.m_strMessageLog = "FPGA.GetAllRegisters() - Connect was not called.";
					return null;
				}
				byte[] byteArray1 = new byte[168];
				int i1 = 0;
				byte[] byteArray2 = BitConverter.GetBytes (43);
				string[] stringArray1 = new string[] { "RegistersThread.ExecuteWorkThread() -  DeviceIoControl - MECConnection0x03d", this.MECConnection.ToString (), " byteRegValue0x03d ", byteArray2.Length.ToString (), " byteResponse0x03d ", byteArray1.Length.ToString () };
				Logging.Instance.Log (4, string.Concat (stringArray1));
				for (i2 = 0; (i2 < byteArray2.Length); i2++)
				{
					Logging.Instance.Log (4, (" " + byteArray2[i2].ToString ()));
				}
				for (i3 = 0; (i3 < byteArray1.Length); i3++)
				{
					Logging.Instance.Log (4, (" " + byteArray1[i3].ToString ()));
				}
				bool b1 = DeviceDriver.DeviceIoControl (this.MECConnection, this.IOCTL_MEC_GET_REGISTER, byteArray2, byteArray2.Length, byteArray1, byteArray1.Length, ref i1, 0);
				if (! b1)
				{
					i4 = Marshal.GetLastWin32Error ();
					this.m_strMessageLog = string.Format ("FPGA.GetRegister() - IOCTL_MEC_GET_REGISTER error 0x03d {0}.", i4);
					stringArray1 = new string[] { "RegistersThread.ExecuteWorkThread() -  DeviceIoControl - bRet0x03d ", b1.ToString (), " iError0x03d ", i4.ToString (), " BufLen0x03d", byteArray1.Length.ToString () };
					Logging.Instance.Log (4, string.Concat (stringArray1));
					return null;
				}
				this.m_strMessageLog = "FPGA.GetRegister() - Successfully got register value.";
				MecRegisters mecRegisters1 = new MecRegisters (byteArray1);
				Logging.Instance.Log (4, ("RegistersThread.ExecuteWorkThread() -  DeviceIoControl - bRet0x03d " + b1.ToString () + " BufLen0x03d" + byteArray1.Length.ToString ()));
				return mecRegisters1;
			}
			
			internal int GetRegister (MecFPGARegister penumRegValue)
			
			{
				int i2;
				if (this.MECConnection == -1)
				{
					this.m_strMessageLog = "FPGA.GetRegister() - Connect was not called.";
					return -1;
				}
				byte[] byteArray1 = new byte[4];
				int i1 = 0;
				byte[] byteArray2 = BitConverter.GetBytes (((int) penumRegValue));
				if (! DeviceDriver.DeviceIoControl (this.MECConnection, this.IOCTL_MEC_GET_REGISTER, byteArray2, byteArray2.Length, byteArray1, byteArray1.Length, ref i1, 0))
				{
					i2 = Marshal.GetLastWin32Error ();
					this.m_strMessageLog = string.Format ("FPGA.GetRegister() - IOCTL_MEC_GET_REGISTER error 0x03d {0}.", i2);
					return -1;
				}
				else
				{
					this.m_strMessageLog = "FPGA.GetRegister() - Successfully got register value.";
					return BitConverter.ToInt32 (byteArray1, 0);
				}
			}
			
			public bool LoadFirmware ()
			
			{
				int i2;
				int i3;
				if (this.MECConnection == -1)
				{
					this.m_strMessageLog = "FPGA.LoadFirmware() - Connect was not called.";
					return false;
				}
				RegistryKeyReader registryKeyReader1 = new RegistryKeyReader ();
				string string1 = registryKeyReader1.GetStringValue (Registry.LocalMachine, "\\Drivers\\BuiltIn\\FPGA", "FPGAFile");
				if (! File.Exists (string1))
				{
					this.m_strMessageLog = "FPGA.LoadFirmware() - File Does Not Exist.";
					return false;
				}
				BinaryReader binaryReader1 = new BinaryReader (((Stream) File.Open (string1, FileMode.Open, FileAccess.Read)));
				byte[] byteArray1 = binaryReader1.ReadBytes (((int) binaryReader1.BaseStream.Length));
				binaryReader1.Close ();
				byte[] byteArray2 = new byte[4];
				int i1 = 0;
				byte[] byteArray3 = BitConverter.GetBytes (0);
				if (! DeviceDriver.DeviceIoControl (this.MECConnection, this.IOCTL_MEC_SET_WDOG_TIME, byteArray3, byteArray3.Length, byteArray2, 0, ref i1, 0))
				{
					i2 = Marshal.GetLastWin32Error ();
					this.m_strMessageLog = string.Format ("FPGA.LoadFirmware() - IOCTL_MEC_SET_WDOG_TIME error 0x03d {0}.", i2);
				}
				bool b2 = DeviceDriver.DeviceIoControl (this.MECConnection, this.IOCTL_MEC_OP_BITSTREAM_LOAD, byteArray1, byteArray1.Length, byteArray2, byteArray2.Length, ref i1, 0);
				if (! b2)
				{
					i3 = Marshal.GetLastWin32Error ();
					this.m_strMessageLog = string.Format ("FPGA.LoadFirmware() - IOCTL_MEC_OP_BITSTREAM_LOAD error 0x03d {0}.", i3);
				}
				else
				{
					this.m_strMessageLog = "FPGA.LoadFirmware() - Success.";
				}
				byteArray3 = BitConverter.GetBytes (4);
				if (DeviceDriver.DeviceIoControl (this.MECConnection, this.IOCTL_MEC_SET_WDOG_TIME, byteArray3, byteArray3.Length, byteArray2, 0, ref i1, 0))
				{
					return b2;
				}
				int i4 = Marshal.GetLastWin32Error ();
				this.m_strMessageLog = string.Format ("FPGA.LoadFirmware() - IOCTL_SET_WDOG_TIME error 0x03d {0}.", i4);
				return b2;
			}
			
			public MecMessage NextEvent ()
			
			{
				int i2;
				if (this.MECConnection == -1)
				{
					this.m_strMessageLog = "FPGA.NextEvent() - Connect was not called.";
					return null;
				}
				byte[] byteArray1 = new byte[4];
				byte[] byteArray2 = new byte[12];
				int i1 = 0;
				if (! DeviceDriver.DeviceIoControl (this.MECConnection, this.IOCTL_MEC_GET_FPGA_MSG, byteArray1, 0, byteArray2, byteArray2.Length, ref i1, 0))
				{
					i2 = Marshal.GetLastWin32Error ();
					this.m_strMessageLog = string.Format ("FPGA.NextEvent() - IOCTL_MEC_GET_FPGA_MSG error 0x03d {0}.", i2);
					return null;
				}
				MecMessage mecMessage1 = new MecMessage (byteArray2);
				this.m_strMessageLog = "FPGA.NextEvent() - Successfully got next message.";
				return mecMessage1;
			}
			
			public MecExceptionMessage NextExceptionEvent ()
			
			{
				int i2;
				if (this.MECConnection == -1)
				{
					this.m_strMessageLog = "FPGA.NextExceptionEvent() - Connect was not called.";
					return null;
				}
				byte[] byteArray1 = new byte[4];
				byte[] byteArray2 = new byte[64];
				int i1 = 0;
				if (! DeviceDriver.DeviceIoControl (this.MECConnection, this.IOCTL_MEC_GET_EXCPT_MSG, byteArray1, 0, byteArray2, byteArray2.Length, ref i1, 0))
				{
					i2 = Marshal.GetLastWin32Error ();
					this.m_strMessageLog = string.Format ("FPGA.NextExceptionEvent() - IOCTL_MEC_GET_EXCPT_MSG error 0x03d {0}.", i2);
					return null;
				}
				MecExceptionMessage mecExceptionMessage1 = new MecExceptionMessage (byteArray2);
				this.m_strMessageLog = "FPGA.NextExceptionEvent() - Successfully got next message.";
				return mecExceptionMessage1;
			}
			
			protected virtual int OpcodeSize (LECHAL.FPGAOpcodes penumOpcode)
			
			{
				LECHAL.FPGAOpcodes fPGAOpcodes1 = penumOpcode;
				if (fPGAOpcodes1 <= LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.ApplicationEvent)
				{
					if (fPGAOpcodes1 <= LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.WaitForMotfCount)
					{
						if (fPGAOpcodes1 == LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetWobble)
						{
							return 8;
						}
						else
						{
							switch (fPGAOpcodes1)
							{
								case  ((LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes) 12555):
								case  ((LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes) 12556):
								
								{
										return 4;
								}
								case LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.LaserOn:
								case LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.LongDelay:
								case LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetLaserPowerChangeDelay:
								case LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetMotfCalFactor:
								case LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.WaitForMotfCount:
								
								{
										return 8;
								}
							}
							return 4;
						}
					}
					if (fPGAOpcodes1 <= LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetJumpSpeed)
					{
						switch (fPGAOpcodes1)
						{
							case LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.WriteAnalog:
							case LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.WriteDigital:
							case LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetMarkSpeed:
							case LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetJumpSpeed:
							
							{
									return 8;
							}
						}
						return 4;
					}
					else if (fPGAOpcodes1 == LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetLaserFPK)
					{
						return 8;
					}
					else if (fPGAOpcodes1 == LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.ApplicationEvent)
					{
						return 8;
					}
					else
					{
						return 4;
					}
				}
				if (fPGAOpcodes1 <= LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetRasterLine)
				{
					if (fPGAOpcodes1 <= LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetRaster)
					{
						if (fPGAOpcodes1 == LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetCorrectionTable)
						{
							return 8;
						}
						else if (fPGAOpcodes1 == LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetRaster)
						{
							return 8;
						}
						else
						{
							return 4;
						}
					}
					if (fPGAOpcodes1 == LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.MotfResetJump)
					{
						return 12;
					}
					else if (fPGAOpcodes1 == LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetRasterLine)
					{
						return 12;
					}
					else
					{
						return 4;
					}
				}
				if (fPGAOpcodes1 <= LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.WaitForIO)
				{
					switch (fPGAOpcodes1)
					{
						case LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetLaserPulse:
						case LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetLaserStandby:
						
						{
								return 12;
						}
					}
					if (fPGAOpcodes1 == LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.WaitForIO)
					{
						return 16;
					}
					else
					{
						return 4;
					}
				}
				if (fPGAOpcodes1 == LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.JumpAbs)
				{
					return 16;
				}
				else if (fPGAOpcodes1 == LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.MarkAbs)
				{
					return 16;
				}
				else
				{
					return 4;
				}
			}
			
			public LECHAL.ResetType Reset ()
			
			{
				int i1 = 0;
				if (this.MECConnection == -1)
				{
					this.m_strMessageLog = "FPGA.Reset() - Connect was not called.";
					return LanmarkControls.LECHardwareAbstraction.LECHAL.ResetType.Failed;
				}
				byte[] byteArray1 = new byte[4];
				byte[] byteArray2 = new byte[4];
				int i2 = 0;
				if (! DeviceDriver.DeviceIoControl (this.MECConnection, this.IOCTL_MEC_OP_ABORT, byteArray1, 0, byteArray2, 0, ref i2, 0))
				{
					i1 = Marshal.GetLastWin32Error ();
					this.m_strMessageLog = string.Format ("FPGA.Reset() - IOCTL_MEC_OP_ABORT error 0x03d {0}.", i1);
					return LanmarkControls.LECHardwareAbstraction.LECHAL.ResetType.Failed;
				}
				LECHAL.ResetType resetType1 = LanmarkControls.LECHardwareAbstraction.LECHAL.ResetType.InProgress;
				this.SendingDataTimestamp = 0;
				if (! DeviceDriver.DeviceIoControl (this.MECConnection, this.IOCTL_MEC_OP_BUFFER_FLUSH, byteArray1, 0, byteArray2, 0, ref i2, 0))
				{
					i1 = Marshal.GetLastWin32Error ();
					this.m_strMessageLog = string.Format ("FPGA.Reset() - IOCTL_MEC_OP_BUFFER_FLUSH error 0x03d {0}.", i1);
					return LanmarkControls.LECHardwareAbstraction.LECHAL.ResetType.Failed;
				}
				byte[] byteArray3 = BitConverter.GetBytes (1);
				if (! DeviceDriver.DeviceIoControl (this.MECConnection, this.IOCTL_MEC_SET_CMD_PROC_STATE, byteArray3, byteArray3.Length, byteArray2, 0, ref i2, 0))
				{
					i1 = Marshal.GetLastWin32Error ();
					this.m_strMessageLog = string.Format ("FPGA.Reset() - IOCTL_MEC_SET_CMD_PROC_STATE error 0x03d {0}.", i1);
					return LanmarkControls.LECHardwareAbstraction.LECHAL.ResetType.Failed;
				}
				else
				{
					this.m_strMessageLog = "FPGA.Reset() - Success.";
					return resetType1;
				}
			}
			
			internal bool ResumeJob ()
			
			{
				byte[] byteArray1;
				byte[] byteArray2;
				int i1;
				if (this.MECConnection == -1)
				{
					return false;
				}
				bool b1 = true;
				if (this.CommandProcessingPaused)
				{
					byteArray1 = new byte[4];
					byteArray2 = new byte[4];
					i1 = 0;
					b1 = DeviceDriver.DeviceIoControl (this.MECConnection, this.IOCTL_MEC_OP_RESUME, byteArray1, 0, byteArray2, 0, ref i1, 0);
				}
				if (! b1)
				{
					int i2 = Marshal.GetLastWin32Error ();
					return false;
				}
				else if (! this.CommandProcessingPaused)
				{
					return true;
				}
				else
				{
					return false;
				}
			}
			
			public bool SendData (byte[] pbyteData)
			
			{
				return this.SendData (pbyteData, pbyteData.Length);
			}
			
			public bool SendData (byte[] pbyteData, int piDataSize)
			
			{
				int i1;
				byte[] byteArray1;
				byte[] byteArray2;
				int i2;
				int i3;
				MecBufferParams mecBufferParams1;
				IntPtr intPtr3;
				int i4;
				byte[] byteArray3;
				int i5;
				int i6;
				int i7;
				int i8;
				Exception exception1;
				int i9;
				if (this.m_bAbort)
				{
					this.m_strMessageLog = "FPGA.SendData() - Abort detected.";
					return false;
				}
				bool b1 = false;
				IntPtr intPtr1 = IntPtr.Zero;
				IntPtr intPtr2 = IntPtr.Zero;
				bool b2 = true;
				this.m_strMessageLog = "FPGA.SendData() - Data successfully sent.";
				if (this.m_bAbort || (this.MECConnection == -1))
				{
					this.m_strMessageLog = "FPGA.SendData() - Connect was not called.";
					return false;
				}
				else
				{
					try
					{
						this.SendingData = true;
						this.SendingDataTimestamp = Environment.TickCount;
						bool b5 = this.StartCommandProcessing (true);
						i1 = piDataSize;
						if (piDataSize > pbyteData.Length)
						{
							i1 = pbyteData.Length;
						}
						byteArray1 = new byte[4];
						byteArray2 = new byte[532];
						i2 = 0;
						b2 = DeviceDriver.DeviceIoControl (this.MECConnection, this.IOCTL_MEC_GET_BUF_POOL_PARAMS, byteArray1, 0, byteArray2, byteArray2.Length, ref i2, 0);
						if (! b2)
						{
							i3 = Marshal.GetLastWin32Error ();
							this.m_strMessageLog = string.Format ("FPGA.SendData() - IOCTL_MEC_GET_BUF_POOL_PARAMS error 0x03d {0}.", i3);
							this.SendingData = false;
							return false;
						}
						else if (this.m_bAbort)
						{
							this.m_strMessageLog = "FPGA.SendData() - Abort detected.";
							this.SendingData = false;
							return false;
						}
						else
						{
							mecBufferParams1 = new MecBufferParams (byteArray2);
							intPtr3 = new IntPtr (-1);
							if ((intPtr2 = MemoryMapFile.CreateFileMapping (intPtr3, 0, 4, 0, mecBufferParams1.BufferSize, mecBufferParams1.MappedFileName)).ToInt32 () == 0)
							{
								this.m_strMessageLog = "FPGA.SendData() - MemoryMapFile.CreateFileMapping failed.";
								this.SendingData = false;
								return false;
							}
							else if (this.m_bAbort)
							{
								b2 = MemoryMapFile.CloseHandle (intPtr2);
								this.m_strMessageLog = "FPGA.SendData() - Abort detected.";
								this.SendingData = false;
								return false;
							}
							else if ((intPtr1 = MemoryMapFile.MapViewOfFile (intPtr2, 4, 0, 0, 0)).ToInt32 () == 0)
							{
								b2 = MemoryMapFile.CloseHandle (intPtr2);
								this.m_strMessageLog = "FPGA.SendData() - MemoryMapFile.MapViewOfFile failed.";
								this.SendingData = false;
								return false;
							}
							else
							{
								i4 = 0;
								byteArray3 = new byte[4];
								byte[] byteArray4 = new byte[28];
								while ((i4 < i1) && (! b1))
								{
									if (! this.m_bAbort)
									{
										if (! DeviceDriver.DeviceIoControl (this.MECConnection, this.IOCTL_MEC_GET_BUF_POOL_SEGMENT, byteArray1, 0, byteArray3, byteArray3.Length, ref i2, 0))
										{
											i8 = Marshal.GetLastWin32Error ();
											if (i8 != 259)
											{
												this.m_strMessageLog = string.Format ("FPGA.SendData() - IOCTL_MEC_GET_BUF_POOL_SEGMENT error 0x03d {0}.", i8);
												b1 = true;
												break;
											}
											if (this.CommandProcessingEnabled && (! this.CommandProcessingPaused))
											{
												Thread.Sleep (0);
												continue;
											}
											bool b6 = this.StartCommandProcessing (true);
											continue;
										}
										if (! this.m_bAbort)
										{
											i5 = BitConverter.ToInt32 (byteArray3, 0);
											i6 = ((mecBufferParams1.SegmentSize > (i1 - i4)) ? (i1 - i4) : mecBufferParams1.SegmentSize);
											Marshal.Copy (pbyteData, i4, ((IntPtr) (intPtr1.ToInt32 () + i5)), i6);
											if (! this.m_bAbort)
											{
												i4 += i6;
												i9 = 0;
												if (DeviceDriver.WriteFile (this.MECConnection, ref i5, i6, out i9, IntPtr.Zero))
												{
													continue;
												}
												i7 = Marshal.GetLastWin32Error ();
												this.m_strMessageLog = string.Format ("FPGA.SendData() - DeviceDriver.WriteFile() error 0x03d {0}.", i7);
												b1 = true;
												break;
											}
											this.m_strMessageLog = "FPGA.SendData() - Abort detected.";
											b1 = true;
											break;
										}
										this.m_strMessageLog = "FPGA.SendData() - Abort detected.";
										b1 = true;
										break;
									}
									this.m_strMessageLog = "FPGA.SendData() - Abort detected.";
									b1 = true;
									break;
								}
							}
						}
					}
					catch (Exception exception2)
					{
						exception1 = exception2;
						Logging.Instance.Log (0, "Exception thrown in FPGA.SendData");
						Logging.Instance.Log (0, exception1.ToString ());
						this.m_strMessageLog = string.Format ("FPGA.SendData() - IOCTL_MEC_GET_BUF_POOL_SEGMENT error 0x03d {0}.", exception1.Message);
						string string1 = exception1.Message;
						b1 = true;
					}
					if (intPtr1.ToInt32 () != 0)
					{
						b2 = MemoryMapFile.UnmapViewOfFile (intPtr1);
					}
					if (intPtr2.ToInt32 () != 0)
					{
						b2 = MemoryMapFile.CloseHandle (intPtr2);
					}
					this.SendingData = false;
					return (! b1);
				}
			}
			
			internal void SetCachedInterlockSetting ()
			
			{
				this.SetInterlockEnable (this.interlockEnabledCache);
			}
			
			internal void SetInterlockEnable (byte AEnable)
			
			{
				int i2;
				int i4;
				if (this.MECConnection == -1)
				{
					this.m_strMessageLog = "FPGA.SetInterlockEnable() - Connect was not called.";
					return;
				}
				byte[] byteArray1 = new byte[4];
				int i1 = 0;
				UInt16 uInt16_1 = ((UInt16) (AEnable << 8));
				uInt16_1 += ((UInt16) this.interlockPolarityCache);
				UInt16 uInt16_2 = ((UInt16) (((int) uInt16_1) & -4097));
				byte[] byteArray2 = BitConverter.GetBytes (uInt16_2);
				if (! DeviceDriver.DeviceIoControl (this.MECConnection, this.IOCTL_MEC_INTERLOCK_CONFIG, byteArray2, byteArray2.Length, byteArray1, 0, ref i1, 0))
				{
					i2 = Marshal.GetLastWin32Error ();
					this.m_strMessageLog = string.Format ("FPGA.SetInterlockEnable() - IOCTL_MEC_INTERLOCK_CONFIG error 0x03d {0}.", i2);
					return;
				}
				int i3 = 0;
				this.interlockEnabledCache = AEnable;
				if ((((int) uInt16_1) & 4096) > 0)
				{
					i3 = 1;
				}
				byte[] byteArray3 = BitConverter.GetBytes (i3);
				if (! DeviceDriver.DeviceIoControl (this.MECConnection, this.IOCTL_MEC_INTERLOCK_ENABLE, byteArray3, byteArray3.Length, byteArray1, 0, ref i1, 0))
				{
					i4 = Marshal.GetLastWin32Error ();
					this.m_strMessageLog = string.Format ("FPGA.SetInterlockEnable() - IOCTL_MEC_INTERLOCK_ENABLE error 0x03d {0}.", i4);
				}
				else
				{
					this.m_strMessageLog = "FPGA.SetInterlockEnable() - Successfully set Interlocks.";
				}
			}
			
			internal void SetInterlockProperties (UInt16 AProperties)
			
			{
				byte[] byteArray1 = BitConverter.GetBytes (AProperties);
				this.interlockPolarityCache = byteArray1[0];
				this.SetInterlockEnable (byteArray1[1]);
			}
			
			public bool StartCommandProcessing (bool pbForce)
			
			{
				byte[] byteArray1;
				byte[] byteArray2;
				int i1;
				int i2;
				byte[] byteArray3;
				byte[] byteArray4;
				int i3;
				int i4;
				if (this.MECConnection == -1)
				{
					this.m_strMessageLog = "FPGA.StartCommandProcessing() - Connect was not called.";
					return false;
				}
				else
				{
					if (pbForce || (! this.CommandProcessingEnabled))
					{
						byteArray1 = BitConverter.GetBytes (1);
						byteArray2 = new byte[4];
						i1 = 0;
						if (! DeviceDriver.DeviceIoControl (this.MECConnection, this.IOCTL_MEC_SET_CMD_PROC_STATE, byteArray1, byteArray1.Length, byteArray2, 0, ref i1, 0))
						{
							i2 = Marshal.GetLastWin32Error ();
							this.m_strMessageLog = string.Format ("FPGA.StartCommandProcessing() - IOCTL_MEC_SET_CMD_PROC_STATE error 0x03d {0}.", i2);
							return false;
						}
					}
					if (pbForce || this.CommandProcessingPaused)
					{
						byteArray3 = new byte[4];
						byteArray4 = new byte[4];
						i3 = 0;
						if (! DeviceDriver.DeviceIoControl (this.MECConnection, this.IOCTL_MEC_OP_RESUME, byteArray3, 0, byteArray4, 0, ref i3, 0))
						{
							i4 = Marshal.GetLastWin32Error ();
							this.m_strMessageLog = string.Format ("FPGA.StartCommandProcessing() - IOCTL_MEC_OP_RESUME error 0x03d {0}.", i4);
							return false;
						}
					}
					this.m_strMessageLog = "FPGA.StartCommandProcessing() - Success.";
					return true;
				}
			}
			
			internal bool SuspendJob ()
			
			{
				byte[] byteArray1;
				byte[] byteArray2;
				int i1;
				if (this.MECConnection == -1)
				{
					return false;
				}
				bool b1 = true;
				if (! this.CommandProcessingPaused)
				{
					byteArray1 = new byte[4];
					byteArray2 = new byte[4];
					i1 = 0;
					b1 = DeviceDriver.DeviceIoControl (this.MECConnection, this.IOCTL_MEC_OP_PAUSE, byteArray1, 0, byteArray2, 0, ref i1, 0);
				}
				if (! b1)
				{
					int i2 = Marshal.GetLastWin32Error ();
					return false;
				}
				else if (this.CommandProcessingPaused)
				{
					return true;
				}
				else
				{
					return false;
				}
			}
			
			protected virtual LECHAL.FPGAOpcodes ToFPGAOpcode (byte[] pbyteData, int piIndex)
			
			{
				LECHAL.FPGAOpcodes fPGAOpcodes1 = this.ToOpcode (BitConverter.ToUInt16 (pbyteData, piIndex));
				this.ToOpcodeEx (fPGAOpcodes1, pbyteData, piIndex);
				return fPGAOpcodes1;
			}
			
			protected virtual LECHAL.FPGAOpcodes ToOpcode (UInt16 psOpcodeValue)
			
			{
				UInt16 uInt16_1 = psOpcodeValue;
				if (uInt16_1 <= 16396)
				{
					if (uInt16_1 <= 4386)
					{
						if (uInt16_1 < 66)
						{
							switch (uInt16_1)
							{
								case 20:
								
								{
										return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.LaserSignalOn;
								}
								case 21:
								
								{
										return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.LaserSignalOff;
								}
								case 65:
								
								{
										return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.BeginJob;
								}
								case 66:
								
								{
										return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.EndJob;
								}
							}
							return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.Unknown;
						}
						else if (uInt16_1 == 264)
						{
							return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetResetJump;
						}
						else if (uInt16_1 == 4163)
						{
							return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.JobMarker;
						}
						else
						{
							switch ((int) uInt16_1)
							{
								case 4354:
								
								{
										return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetLaserPower;
								}
								case 4355:
								
								{
										return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetLaserOffDelay;
								}
								case 4357:
								
								{
										return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetWobble;
								}
								case 4358:
								
								{
										return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.WobbleEnable;
								}
								case 4361:
								
								{
										return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetMotfMode;
								}
								case 4363:
								
								{
										return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetMotfDirection;
								}
								case 4364:
								
								{
										return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.EnableMotf;
								}
								case 4370:
								
								{
										return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetActiveCorrectionTable;
								}
								case 4371:
								
								{
										return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetFIFOCounter;
								}
								case 4372:
								
								{
										return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetLaserModeConfig;
								}
								case 4373:
								
								{
										return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetLaserTiming;
								}
								case 4377:
								
								{
										return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetLaserModDelay;
								}
								case 4378:
								
								{
										return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetEnableLaser;
								}
								case 4379:
								
								{
										return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetLaserEnableDelay;
								}
								case 4380:
								
								{
										return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetLaserEnableTimeout;
								}
								case 4381:
								
								{
										return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetGalvoDACConfig;
								}
								case 4384:
								
								{
										return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetLaserPipelineDelay;
								}
								case 4385:
								
								{
										return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetMicrovectorDelay;
								}
								case 4386:
								
								{
										return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetServoConfig;
								}
								case 4356:
								case 4359:
								case 4360:
								case 4362:
								case 4365:
								case 4366:
								case 4367:
								case 4368:
								case 4369:
								case 4374:
								case 4375:
								case 4376:
								case 4382:
								case 4383:
								
								{
										return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.Unknown;
								}
							}
							return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.Unknown;
						}
					}
					if (uInt16_1 < 8452)
					{
						if (uInt16_1 == 5121)
						{
							return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.OutputDrawList;
						}
						else if (uInt16_1 == 8452)
						{
							return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetLaserOnDelay;
						}
						else
						{
							return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.Unknown;
						}
					}
					switch ((int) uInt16_1)
					{
						case 12289:
						
						{
								return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.LaserOn;
						}
						case 12290:
						
						{
								return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.LongDelay;
						}
						case 12553:
						
						{
								return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetLaserPowerChangeDelay;
						}
						case 12554:
						
						{
								return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetMotfCalFactor;
						}
						case 12555:
						case 12556:
						
						{
								return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.Unknown;
						}
						case 12557:
						
						{
								return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.WaitForMotfCount;
						}
						case 16395:
						
						{
								return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.WriteAnalog;
						}
						case 16396:
						
						{
								return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.WriteDigital;
						}
					}
					return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.Unknown;
				}
				else
				{
					if (uInt16_1 < 24838)
					{
						if (uInt16_1 < 16657)
						{
							switch ((int) uInt16_1)
							{
								case 16640:
								
								{
										return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetMarkSpeed;
								}
								case 16641:
								
								{
										return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetJumpSpeed;
								}
							}
							if (uInt16_1 == 16657)
							{
								return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetCorrectionTable;
							}
							else
							{
								return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.Unknown;
							}
						}
						if (uInt16_1 == 16664)
						{
							return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetLaserFPK;
						}
						else if (uInt16_1 == 20544)
						{
							return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.ApplicationEvent;
						}
						else if (uInt16_1 == 24838)
						{
							return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetRaster;
						}
						else
						{
							return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.Unknown;
						}
					}
					if (uInt16_1 < 37143)
					{
						if (uInt16_1 == 28942)
						{
							return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.MotfResetJump;
						}
						else if (uInt16_1 == 33031)
						{
							return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetRasterLine;
						}
						else
						{
							switch ((int) uInt16_1)
							{
								case 37142:
								
								{
										return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetLaserPulse;
								}
								case 37143:
								
								{
										return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.SetLaserStandby;
								}
							}
							return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.Unknown;
						}
					}
					if (uInt16_1 == 37151)
					{
						return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.WaitForIO;
					}
					else if (uInt16_1 == 45056)
					{
						return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.JumpAbs;
					}
					else if (uInt16_1 == 45059)
					{
						return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.MarkAbs;
					}
					else
					{
						return LanmarkControls.LECHardwareAbstraction.LECHAL.FPGAOpcodes.Unknown;
					}
				}
			}
			
			private void ToOpcodeEx (LECHAL.FPGAOpcodes poCode, byte[] pbyteData, int piIndex)
			
			{
			}
			
		#endregion
	}
	
}

