//
// Decompiled with: Decompiler.NET, Version=2.0.0.230, Culture=neutral, PublicKeyToken=null, Version: 2.0.0.230
// Decompilation Started at: 14/02/2008 11:22:16
// Copyright 2003 - 2004, Jungle Creatures, Inc., All Rights Reserved. http://www.junglecreatures.com/
// Written by Jonathan Pierce, Email: support@junglecreatures.com
//

namespace LanmarkControls.LECHardwareAbstraction

{
		
		#region Namespace Import Declarations
		
			using LanmarkControls.CommonLib.General;
			using LanmarkControls.CommonLib.Protocol;
			using LanmarkControls.LECHardwareAbstraction.FPGAInterface;
			using LanmarkControls.LECHardwareAbstraction.SerialPortInterface;
			using LanmarkControls.LECHardwareAbstraction.Utilities;
			using System;
			using System.IO;
			using System.Runtime.InteropServices;
			using System.Threading;
			
		#endregion
		
	public sealed class LECHAL
	
	{
		
		#region Fields
			private Matrix alignMatrix;
			private bool com1Connected;
			private bool com2Connected;
			public const int Error_FPGAConnect = 3;
			public const int Error_FPGAFirmwareLoad = 1;
			public const int Error_FPGAReset = 2;
			internal FPGA fpgaInterface;
			private Matrix hardwareMatrix;
			private static readonly LECHAL instanceLECHAL;
			private bool leadingEdgeDetected;
			public const short LsrMode_Activate = 256;
			public const short LsrMode_EnablePolarity = 64;
			public const short LsrMode_FPKPolarity = 32;
			public const short LsrMode_Mod1Polarity = 8;
			public const short LsrMode_Mod2Polarity = 16;
			public const short LsrMode_On1Polarity = 1;
			public const short LsrMode_On2Cfg0 = 1024;
			public const short LsrMode_On2Cfg1 = 2048;
			public const short LsrMode_On2Polarity = 2;
			public const short LsrMode_PowerDOutPolarity = 128;
			public const short LsrMode_PowerMode = 512;
			public const short LsrMode_ReservedPolarity = 4;
			private bool m_bFixDataProcessed;
			private bool m_bGetRegisters;
			private ControlConfigReader m_oCurrentControl;
			private CorrTableReader m_oCurrentCorr1;
			private string m_oCurrentCorr1FileName;
			private UserConfigReader m_oCurrentCorr1Settings;
			private CorrTableReader m_oCurrentCorr2;
			private string m_oCurrentCorr2FileName;
			private UserConfigReader m_oCurrentCorr2Settings;
			private AtUpdateCorrInfo m_oCurrentCorrectionInfo;
			private LaserConfigReader m_oCurrentLaser;
			private string m_oCurrentLaserFileName;
			private LensConfigReader m_oCurrentLens;
			private string m_oCurrentLensFileName;
			private UserConfigReader m_oCurrentUser;
			private string m_oCurrentUserFileName;
			private PerformanceMatrixData m_oPerformanceData;
			private BinaryWriter m_oWriter;
			private int maxBufferSize;
			private Matrix objectMatrix;
			private Matrix stepRepeatMatrix;
			public const int Success = 0;
		#endregion
		
		#region Nested Types
		
			internal enum FPGAAppEvents
			
			{
				BeginJob = 0, 
				EndJob = 1, 
				BeginObject = 2, 
				EndObject = 3, 
				BeginTask = 4, 
				EndTask = 5, 
				MarkProgress = 6, 
				CycleProgress = 7, 
				UpdateDetect = 8, 
				UpdateCycleTime = 9, 
				UpdateObjectTime = 10, 
				JobAbort = 11, 
				ConnectionLost = 12, 
				Error = 13, 
				DriverError = 14, 
				FixDataProcessed = 15, 
				GetRegisters = 16, 
			}
			
			
			public enum FPGAExceptMessage
			
			{
				QueueFull = 8001, 
				ProcessAbort = 9001, 
				FifoEmptyTimeout = 9002, 
				EventTimeout = 9003, 
				BadOpcode = 9004, 
				FirmwareBug = 9005, 
				WriteDigitalBad = 9006, 
				SetLaserPowerBad = 9007, 
				SetCorrectionTableBad = 9008, 
				SetLaserPulseBad = 9009, 
				WaitForIOBad = 9010, 
				WaitForIOTimeout = 9011, 
				SetLaserStandbyBad = 9012, 
				CPLDTimeout = 9013, 
				LaserActiveTimeout = 9014, 
				ServoFault = 9020, 
				Interlock = 9021, 
				SetMblazeRegBad = 9101, 
				GetMblazeRegBad = 9102, 
				SetDACValueBad = 9103, 
				GetCorrectionTableBad = 9104, 
				Error = 42616, 
			}
			
			
			public enum FPGAOpcodes
			
			{
				Unknown = -1, 
				JumpAbs = 45056, 
				LaserOn = 12289, 
				LongDelay = 12290, 
				MarkAbs = 45059, 
				WriteAnalog = 16395, 
				WriteDigital = 16396, 
				LaserSignalOn = 20, 
				LaserSignalOff = 21, 
				ApplicationEvent = 20544, 
				BeginJob = 65, 
				EndJob = 66, 
				JobMarker = 4163, 
				SetMarkSpeed = 16640, 
				SetJumpSpeed = 16641, 
				SetPMMarkSpeedPct = 12579, 
				SetLaserPower = 4354, 
				SetLaserOffDelay = 4355, 
				SetPMLaserPowerPct = 12580, 
				SetLaserOnDelay = 8452, 
				SetWobble = 4357, 
				WobbleEnable = 4358, 
				SetRaster = 24838, 
				SetRasterLine = 33031, 
				SetResetJump = 264, 
				SetPMFieldOffset = 24871, 
				SetPMFieldOrientation = 4392, 
				SetMotfMode = 4361, 
				SetMotfDirection = 4363, 
				EnableMotf = 4364, 
				SetLaserPowerChangeDelay = 12553, 
				SetMotfCalFactor = 12554, 
				WaitForMotfCount = 12557, 
				MotfResetJump = 28942, 
				SetCorrectionTable = 20753, 
				SetActiveCorrectionTable = 4370, 
				SetFIFOCounter = 4371, 
				SetLaserModeConfig = 4372, 
				SetLaserTiming = 4373, 
				SetLaserPulse = 37142, 
				SetLaserStandby = 37143, 
				SetPMPulseWidthPct = 12581, 
				SetPMPulsePeriodPct = 12582, 
				SetLaserFPK = 16664, 
				SetLaserModDelay = 4377, 
				SetEnableLaser = 4378, 
				SetLaserEnableDelay = 4379, 
				SetLaserEnableTimeout = 4380, 
				SetGalvoDACConfig = 4381, 
				WaitForIO = 37151, 
				SetLaserPipelineDelay = 4384, 
				SetMicrovectorDelay = 4385, 
				SetServoConfig = 4386, 
				OutputTDData = 21504, 
				OutputDrawList = 5121, 
			}
			
			
			internal enum MecFPGAEvent
			
			{
				MecFPGAEvent_ILLEGAL = -1, 
				MecFPGAEvent_MSG = 0, 
				MecFPGAEvent_EXCPTMSG = 1, 
				MecFPGAEvent_WDOG = 2, 
				MecFPGAEvent_DATA = 3, 
				MecFPGAEvent_LAST = 4, 
			}
			
			
			public enum ResetType
			
			{
				InProgress = 0, 
				Complete = 1, 
				Failed = 2, 
			}
			
			
			internal enum TransformType
			
			{
				Gain = 4, 
				Offset = 2, 
				Rotation = 1, 
			}
			
		#endregion
		
		#region Constructors
		
			static LECHAL ()
			
			{
				LECHAL.instanceLECHAL = new LECHAL ();
			}
			
			
			private LECHAL ()
			
			{
				this.alignMatrix = ((Matrix) null);
				this.hardwareMatrix = ((Matrix) null);
				this.objectMatrix = ((Matrix) null);
				this.stepRepeatMatrix = ((Matrix) null);
				this.m_bGetRegisters = false;
				this.m_bFixDataProcessed = false;
				this.fpgaInterface = ((FPGA) null);
				this.m_oWriter = ((BinaryWriter) null);
				this.m_oCurrentCorrectionInfo = ((AtUpdateCorrInfo) null);
				this.maxBufferSize = 0;
				this.leadingEdgeDetected = false;
				this.com1Connected = false;
				this.com2Connected = false;
				this.m_oCurrentUserFileName = "";
				this.m_oCurrentUser = ((UserConfigReader) null);
				this.m_oCurrentControl = ((ControlConfigReader) null);
				this.m_oCurrentLaserFileName = "";
				this.m_oCurrentLaser = ((LaserConfigReader) null);
				this.m_oCurrentLensFileName = "";
				this.m_oCurrentLens = ((LensConfigReader) null);
				this.m_oCurrentCorr1FileName = "";
				this.m_oCurrentCorr1Settings = ((UserConfigReader) null);
				this.m_oCurrentCorr1 = ((CorrTableReader) null);
				this.m_oCurrentCorr2FileName = "";
				this.m_oCurrentCorr2Settings = ((UserConfigReader) null);
				this.m_oCurrentCorr2 = ((CorrTableReader) null);
				this.m_oPerformanceData = ((PerformanceMatrixData) null);
				this.fpgaInterface = new FPGA ();
				this.alignMatrix = new Matrix ();
				this.alignMatrix.SetToIdentity ();
				this.hardwareMatrix = new Matrix ();
				this.hardwareMatrix.SetToIdentity ();
				this.objectMatrix = new Matrix ();
				this.objectMatrix.SetToIdentity ();
				this.stepRepeatMatrix = new Matrix ();
				this.stepRepeatMatrix.SetToIdentity ();
			}
			
		#endregion
		
		#region Properties
		
			private Matrix AlignMatrix
			
			{
				get
				{
					Matrix matrix1;
					Matrix matrix2 = this.alignMatrix;
					lock (matrix2)
					{
						matrix1 = this.alignMatrix;
					}
					return matrix1;
				}
				set
				{
					Matrix matrix1 = this.alignMatrix;
					lock (matrix1)
					{
						this.alignMatrix = value;
					}
				}
			}
			
			
			public bool bFixDataProcessed
			
			{
				get
				{
					return this.m_bFixDataProcessed;
				}
				set
				{
					this.m_bFixDataProcessed = value;
				}
			}
			
			
			private ControlConfigReader CurrentControl
			
			{
				get
				{
					string string1;
					BaseConfig baseConfig1;
					Exception exception1;
					try
					{
						if ((this.m_oCurrentControl == null) && Directory.Exists (CommonSvrUtil.FullConfigPath))
						{
							string1 = Path.GetFileName (AdminSettings.DataSettings.ControlFile);
							if (File.Exists (Path.Combine (CommonSvrUtil.FullConfigPath, string1)))
							{
								baseConfig1 = IdentifyReader.IdentifyConfigurationFile (string1);
								if ((baseConfig1 != null) && (baseConfig1 is ControlConfigReader))
								{
									this.m_oCurrentControl = (baseConfig1 as ControlConfigReader);
								}
							}
						}
						return this.m_oCurrentControl;
					}
					catch (Exception exception2)
					{
						exception1 = exception2;
						Logging.Instance.Log (0, string.Format (("DataThread.CurrentControl Property - Exception error 0x03d " + exception1.Message), new object[0]));
						Logging.Instance.Log (0, exception1.ToString ());
					}
					return null;
				}
				set
				{
					this.m_oCurrentControl = value;
				}
			}
			
			
			private CorrTableReader CurrentCorr1
			
			{
				get
				{
					string string1;
					BaseConfig baseConfig1;
					Exception exception1;
					try
					{
						if ((this.m_oCurrentCorr1 != null) && (! this.Corr1Match ()))
						{
							this.m_oCurrentCorr1 = ((CorrTableReader) null);
							this.m_oCurrentCorr1FileName = "";
							this.CurrentCorr1Settings = ((UserConfigReader) null);
						}
						if ((this.m_oCurrentCorr1 == null) && (this.CurrentControl != null))
						{
							this.m_oCurrentCorr1FileName = "";
							this.CurrentCorr1Settings = ((UserConfigReader) null);
							if (Directory.Exists (CommonSvrUtil.FullConfigPath))
							{
								string1 = Path.Combine (CommonSvrUtil.FullConfigPath, this.CurrentControl.CorrFile1);
								if (Path.GetExtension (string1).Length == 0)
								{
									string1 = (string1 + ".xml");
								}
								if (File.Exists (string1))
								{
									baseConfig1 = IdentifyReader.IdentifyConfigurationFile (string1);
									if ((baseConfig1 != null) && (baseConfig1 is CorrTableReader))
									{
										this.m_oCurrentCorr1 = (baseConfig1 as CorrTableReader);
										this.m_oCurrentCorr1FileName = this.CurrentControl.CorrFile1;
									}
								}
							}
						}
						return this.m_oCurrentCorr1;
					}
					catch (Exception exception2)
					{
						exception1 = exception2;
						Logging.Instance.Log (0, string.Format (("DataThread.CurrentCorr1 Property - Exception error 0x03d " + exception1.Message), new object[0]));
						Logging.Instance.Log (0, exception1.ToString ());
					}
					return null;
				}
				set
				{
					if (this.m_oCurrentCorr1 != value)
					{
						this.m_oCurrentCorr1 = value;
						this.m_oCurrentCorr1FileName = "";
						this.CurrentCorr1Settings = ((UserConfigReader) null);
					}
				}
			}
			
			
			private string CurrentCorr1FileName
			
			{
				get
				{
					return this.m_oCurrentCorr1FileName;
				}
				set
				{
					this.m_oCurrentCorr1FileName = value;
				}
			}
			
			
			private UserConfigReader CurrentCorr1Settings
			
			{
				get
				{
					return this.m_oCurrentCorr1Settings;
				}
				set
				{
					this.m_oCurrentCorr1Settings = value;
				}
			}
			
			
			private CorrTableReader CurrentCorr2
			
			{
				get
				{
					string string1;
					BaseConfig baseConfig1;
					Exception exception1;
					try
					{
						if ((this.m_oCurrentCorr2 != null) && (! this.Corr2Match ()))
						{
							this.m_oCurrentCorr2 = ((CorrTableReader) null);
							this.m_oCurrentCorr2FileName = "";
							this.CurrentCorr2Settings = ((UserConfigReader) null);
						}
						if ((this.m_oCurrentCorr2 == null) && (this.CurrentControl != null))
						{
							this.m_oCurrentCorr2FileName = "";
							this.CurrentCorr2Settings = ((UserConfigReader) null);
							if (Directory.Exists (CommonSvrUtil.FullConfigPath))
							{
								string1 = Path.Combine (CommonSvrUtil.FullConfigPath, this.CurrentControl.CorrFile2);
								if (Path.GetExtension (string1).Length == 0)
								{
									string1 = (string1 + ".xml");
								}
								if (File.Exists (string1))
								{
									baseConfig1 = IdentifyReader.IdentifyConfigurationFile (string1);
									if ((baseConfig1 != null) && (baseConfig1 is CorrTableReader))
									{
										this.m_oCurrentCorr2 = (baseConfig1 as CorrTableReader);
										this.m_oCurrentCorr2FileName = this.CurrentControl.CorrFile2;
									}
								}
							}
						}
						return this.m_oCurrentCorr2;
					}
					catch (Exception exception2)
					{
						exception1 = exception2;
						Logging.Instance.Log (0, string.Format (("DataThread.CurrentCorr2 Property - Exception error 0x03d " + exception1.Message), new object[0]));
						Logging.Instance.Log (0, exception1.ToString ());
					}
					return null;
				}
				set
				{
					if (this.m_oCurrentCorr2 != value)
					{
						this.m_oCurrentCorr2 = value;
						this.m_oCurrentCorr2FileName = "";
						this.CurrentCorr2Settings = ((UserConfigReader) null);
					}
				}
			}
			
			
			private string CurrentCorr2FileName
			
			{
				get
				{
					return this.m_oCurrentCorr2FileName;
				}
				set
				{
					this.m_oCurrentCorr2FileName = value;
				}
			}
			
			
			private UserConfigReader CurrentCorr2Settings
			
			{
				get
				{
					return this.m_oCurrentCorr2Settings;
				}
				set
				{
					this.m_oCurrentCorr2Settings = value;
				}
			}
			
			
			public LaserConfigReader CurrentLaser
			
			{
				get
				{
					string string1;
					BaseConfig baseConfig1;
					Exception exception1;
					try
					{
						if ((this.m_oCurrentLaser != null) && (! this.LaserMatch ()))
						{
							this.m_oCurrentLaser = ((LaserConfigReader) null);
							this.m_oCurrentLaserFileName = "";
						}
						if ((this.m_oCurrentLaser == null) && (this.CurrentControl != null))
						{
							this.m_oCurrentLaserFileName = "";
							if (Directory.Exists (CommonSvrUtil.FullConfigPath))
							{
								string1 = Path.Combine (CommonSvrUtil.FullConfigPath, this.CurrentControl.LaserFile);
								if (Path.GetExtension (string1).Length == 0)
								{
									string1 = (string1 + ".xml");
								}
								if (File.Exists (string1))
								{
									baseConfig1 = IdentifyReader.IdentifyConfigurationFile (string1);
									if ((baseConfig1 != null) && (baseConfig1 is LaserConfigReader))
									{
										this.m_oCurrentLaser = (baseConfig1 as LaserConfigReader);
										this.m_oCurrentLaserFileName = this.CurrentControl.LaserFile;
									}
								}
							}
						}
						return this.m_oCurrentLaser;
					}
					catch (Exception exception2)
					{
						exception1 = exception2;
						Logging.Instance.Log (0, string.Format (("DataThread.CurrentLaser Property - Exception error 0x03d " + exception1.Message), new object[0]));
						Logging.Instance.Log (0, exception1.ToString ());
					}
					return null;
				}
				set
				{
					if (this.m_oCurrentLaser != value)
					{
						this.m_oCurrentLaser = value;
						this.m_oCurrentLaserFileName = "";
					}
				}
			}
			
			
			private string CurrentLaserFileName
			
			{
				get
				{
					return this.m_oCurrentLaserFileName;
				}
				set
				{
					this.m_oCurrentLaserFileName = value;
				}
			}
			
			
			public LensConfigReader CurrentLens
			
			{
				get
				{
					string string1;
					BaseConfig baseConfig1;
					Exception exception1;
					try
					{
						if ((this.m_oCurrentLens != null) && (! this.LensMatch ()))
						{
							this.m_oCurrentLens = ((LensConfigReader) null);
							this.m_oCurrentLensFileName = "";
						}
						if ((this.m_oCurrentLens == null) && (this.CurrentControl != null))
						{
							this.m_oCurrentLensFileName = "";
							if (Directory.Exists (CommonSvrUtil.FullConfigPath))
							{
								string1 = Path.Combine (CommonSvrUtil.FullConfigPath, this.CurrentControl.LensFile);
								if (Path.GetExtension (string1).Length == 0)
								{
									string1 = (string1 + ".xml");
								}
								if (File.Exists (string1))
								{
									baseConfig1 = IdentifyReader.IdentifyConfigurationFile (string1);
									if ((baseConfig1 != null) && (baseConfig1 is LensConfigReader))
									{
										this.m_oCurrentLens = (baseConfig1 as LensConfigReader);
										this.m_oCurrentLensFileName = this.CurrentControl.LensFile;
									}
								}
							}
						}
						return this.m_oCurrentLens;
					}
					catch (Exception exception2)
					{
						exception1 = exception2;
						Logging.Instance.Log (0, string.Format (("DataThread.CurrentLens Property - Exception error 0x03d " + exception1.Message), new object[0]));
						Logging.Instance.Log (0, exception1.ToString ());
					}
					return null;
				}
				set
				{
					if (this.m_oCurrentLens != value)
					{
						this.m_oCurrentLens = value;
						this.m_oCurrentLensFileName = "";
					}
				}
			}
			
			
			private string CurrentLensFileName
			
			{
				get
				{
					return this.m_oCurrentLensFileName;
				}
				set
				{
					this.m_oCurrentLensFileName = value;
				}
			}
			
			
			public PerformanceMatrixData CurrentPerformance
			
			{
				get
				{
					string string1;
					BaseConfig baseConfig1;
					Exception exception1;
					try
					{
						if ((this.m_oPerformanceData == null) && Directory.Exists (CommonSvrUtil.FullConfigPath))
						{
							string1 = Path.Combine (CommonSvrUtil.FullConfigPath, Path.GetFileName (this.CurrentControl.PerformanceFile));
							if (Path.GetExtension (string1).Length == 0)
							{
								string1 = (string1 + ".xml");
							}
							if (File.Exists (string1))
							{
								baseConfig1 = IdentifyReader.IdentifyConfigurationFile (string1);
								if ((baseConfig1 != null) && (baseConfig1 is PerformanceMatrixData))
								{
									this.m_oPerformanceData = (baseConfig1 as PerformanceMatrixData);
								}
							}
						}
						return this.m_oPerformanceData;
					}
					catch (Exception exception2)
					{
						exception1 = exception2;
						Logging.Instance.Log (0, string.Format (("DataThread.CurrentPerformance Property - Exception error 0x03d " + exception1.Message), new object[0]));
						Logging.Instance.Log (0, exception1.ToString ());
					}
					return null;
				}
				set
				{
					if (this.m_oPerformanceData != value)
					{
						this.m_oPerformanceData = value;
					}
				}
			}
			
			
			private UserConfigReader CurrentUser
			
			{
				get
				{
					string string1;
					BaseConfig baseConfig1;
					Exception exception1;
					try
					{
						if ((this.m_oCurrentUser != null) && (! this.UserMatch ()))
						{
							this.m_oCurrentUser = ((UserConfigReader) null);
							this.m_oCurrentUserFileName = "";
						}
						if ((this.m_oCurrentUser == null) && (this.CurrentControl != null))
						{
							this.m_oCurrentUserFileName = "";
							if (Directory.Exists (CommonSvrUtil.FullConfigPath))
							{
								string1 = Path.Combine (CommonSvrUtil.FullConfigPath, this.CurrentControl.UserFile);
								if (Path.GetExtension (string1).Length == 0)
								{
									string1 = (string1 + ".xml");
								}
								if (File.Exists (string1))
								{
									baseConfig1 = IdentifyReader.IdentifyConfigurationFile (string1);
									if ((baseConfig1 != null) && (baseConfig1 is UserConfigReader))
									{
										this.m_oCurrentUser = (baseConfig1 as UserConfigReader);
										this.m_oCurrentUserFileName = this.CurrentControl.UserFile;
									}
								}
							}
						}
						return this.m_oCurrentUser;
					}
					catch (Exception exception2)
					{
						exception1 = exception2;
						Logging.Instance.Log (0, string.Format (("DataThread.CurrentUser Property - Exception error 0x03d " + exception1.Message), new object[0]));
						Logging.Instance.Log (0, exception1.ToString ());
					}
					return null;
				}
				set
				{
					if (this.m_oCurrentUser != value)
					{
						this.m_oCurrentUser = value;
						this.m_oCurrentUserFileName = "";
					}
				}
			}
			
			
			private string CurrentUserFileName
			
			{
				get
				{
					return this.m_oCurrentUserFileName;
				}
				set
				{
					this.m_oCurrentUserFileName = value;
				}
			}
			
			
			public bool DoGetRegisters
			
			{
				get
				{
					return this.m_bGetRegisters;
				}
				set
				{
					this.m_bGetRegisters = value;
				}
			}
			
			
			public bool FPGAAbortState
			
			{
				get
				{
					return this.fpgaInterface.Abort;
				}
				set
				{
					this.fpgaInterface.Abort = value;
				}
			}
			
			
			public string FPGAMessageLog
			
			{
				get
				{
					return this.fpgaInterface.MessageLog;
				}
			}
			
			
			public bool FPGASendingData
			
			{
				get
				{
					return this.fpgaInterface.SendingData;
				}
				set
				{
					this.fpgaInterface.SendingData = value;
				}
			}
			
			
			private Matrix HardwareMatrix
			
			{
				get
				{
					Matrix matrix1;
					Matrix matrix2 = this.hardwareMatrix;
					lock (matrix2)
					{
						matrix1 = this.hardwareMatrix;
					}
					return matrix1;
				}
				set
				{
					Matrix matrix1 = this.hardwareMatrix;
					lock (matrix1)
					{
						this.hardwareMatrix = value;
					}
				}
			}
			
			
			public static LECHAL Instance
			
			{
				get
				{
					return LECHAL.instanceLECHAL;
				}
			}
			
			
			private Matrix ObjectMatrix
			
			{
				get
				{
					Matrix matrix1;
					Matrix matrix2 = this.objectMatrix;
					lock (matrix2)
					{
						matrix1 = this.objectMatrix;
					}
					return matrix1;
				}
				set
				{
					Matrix matrix1 = this.objectMatrix;
					lock (matrix1)
					{
						this.objectMatrix = value;
					}
				}
			}
			
			
			private Matrix StepRepeatMatrix
			
			{
				get
				{
					Matrix matrix1;
					Matrix matrix2 = this.stepRepeatMatrix;
					lock (matrix2)
					{
						matrix1 = this.stepRepeatMatrix;
					}
					return matrix1;
				}
				set
				{
					Matrix matrix1 = this.stepRepeatMatrix;
					lock (matrix1)
					{
						this.stepRepeatMatrix = value;
					}
				}
			}
			
			
			public IPConfig WinCEIPSettings
			
			{
				get
				{
					PLI pLI1 = new PLI ();
					bool b1 = pLI1.Connect ();
					IPConfig iPConfig1 = new IPConfig ();
					bool b2 = pLI1.getIPConfig (iPConfig1);
					bool b3 = pLI1.Disconnect ();
					return iPConfig1;
				}
				set
				{
					PLI pLI1 = new PLI ();
					bool b1 = pLI1.Connect ();
					bool b2 = pLI1.setIPConfig (value);
					bool b3 = pLI1.Disconnect ();
				}
			}
			
		#endregion
		
		#region Methods
		
			public uint CalcQualifiedInterlocks (uint uiInterlockBits)
			
			{
				return this.fpgaInterface.CalcQualifiedInterlocks (uiInterlockBits);
			}
			
			public void ClearFPGAEventQueue ()
			
			{
				bool b1 = this.fpgaInterface.ClearMessageQueue ();
			}
			
			public void ClearFPGAExceptionEventQueue ()
			
			{
				bool b1 = this.fpgaInterface.ClearExceptMessageQueue ();
			}
			
			public bool CloseCOMPort (Port portObject)
			
			{
				if (portObject.PortName == "COM1:")
				{
					this.com1Connected = false;
				}
				if (portObject.PortName == "COM2:")
				{
					this.com2Connected = false;
				}
				bool b1 = portObject.Close ();
				portObject.Dispose ();
				return b1;
			}
			
			private PerformanceMatrixData CombineLensTable1Values ()
			
			{
				float single1;
				PerformanceMatrixData performanceMatrixData1;
				Exception exception1;
				PerformanceMatrixData performanceMatrixData2;
				try
				{
					single1 = this.CurrentLens.Table1Rotation;
					performanceMatrixData1 = new PerformanceMatrixData ();
					if (single1 < 0F)
					{
						single1 = (360F - single1);
					}
					if (single1 >= 270F)
					{
						performanceMatrixData1.FieldOrientation = 270;
					}
					else if (((double) single1) >= 180D)
					{
						performanceMatrixData1.FieldOrientation = 180;
					}
					else if (((double) single1) >= 90D)
					{
						performanceMatrixData1.FieldOrientation = 90;
					}
					else
					{
						performanceMatrixData1.FieldOrientation = ushort.MinValue;
					}
					performanceMatrixData1.XOffset = ((short) (this.CurrentPerformance.XOffset + this.CurrentLens.Table1XOffset));
					performanceMatrixData1.YOffset = ((short) (this.CurrentPerformance.YOffset + this.CurrentLens.Table1YOffset));
					performanceMatrixData1.ZOffset = this.CurrentPerformance.ZOffset;
					performanceMatrixData1.LaserPowerPercent = this.CurrentPerformance.LaserPowerPercent;
					performanceMatrixData1.MarkSpeedPercent = this.CurrentPerformance.MarkSpeedPercent;
					performanceMatrixData1.PeriodPercent = this.CurrentPerformance.PeriodPercent;
					performanceMatrixData1.PulseWidthPercent = this.CurrentPerformance.PulseWidthPercent;
					performanceMatrixData2 = performanceMatrixData1;
				}
				catch (Exception exception2)
				{
					exception1 = exception2;
					Logging.Instance.Log (0, string.Format (("LECHAL.CombineLensTable1Values() - Exception error 0x03d " + exception1.Message), new object[0]));
					Logging.Instance.Log (0, exception1.ToString ());
					performanceMatrixData2 = ((PerformanceMatrixData) null);
				}
				return performanceMatrixData2;
			}
			
			private bool Corr1Match ()
			
			{
				return this.Corr1Match (((string) null));
			}
			
			private bool Corr1Match (string pstrCorr1Name)
			
			{
				Exception exception1;
				try
				{
					if (this.CurrentControl == null)
					{
						return false;
					}
					else if ((pstrCorr1Name == null) || (pstrCorr1Name.Length == 0))
					{
						return (this.m_oCurrentCorr1FileName.CompareTo (this.CurrentControl.CorrFile1) == 0);
					}
					else
					{
						return (this.m_oCurrentCorr1FileName.CompareTo (pstrCorr1Name) == 0);
					}
				}
				catch (Exception exception2)
				{
					exception1 = exception2;
					Logging.Instance.Log (0, string.Format (("DataThread.Corr1Match() - Exception error 0x03d " + exception1.Message), new object[0]));
					Logging.Instance.Log (0, exception1.ToString ());
				}
				return false;
			}
			
			private bool Corr2Match (string pstrCorr2Name)
			
			{
				Exception exception1;
				try
				{
					if (this.CurrentControl == null)
					{
						return false;
					}
					else if ((pstrCorr2Name == null) || (pstrCorr2Name.Length == 0))
					{
						return (this.m_oCurrentCorr2FileName.CompareTo (this.CurrentControl.CorrFile2) == 0);
					}
					else
					{
						return (this.m_oCurrentCorr2FileName.CompareTo (pstrCorr2Name) == 0);
					}
				}
				catch (Exception exception2)
				{
					exception1 = exception2;
					Logging.Instance.Log (0, string.Format (("DataThread.Corr2Match() - Exception error 0x03d " + exception1.Message), new object[0]));
					Logging.Instance.Log (0, exception1.ToString ());
				}
				return false;
			}
			
			private bool Corr2Match ()
			
			{
				return this.Corr2Match (((string) null));
			}
			
			public void EnableFPGAEventQueue (bool enableEvents)
			
			{
				bool b1 = this.fpgaInterface.EnableMsgQueue (enableEvents);
			}
			
			private void ExtractOrientationandOffset (UserConfigReader poReader, int tableNumber)
			
			{
				PerformanceMatrixData performanceMatrixData1;
				Exception exception1;
				try
				{
					if (tableNumber != 1)
					{
						poReader.Rotation = 0F;
					}
					else
					{
						performanceMatrixData1 = new PerformanceMatrixData ();
						if (poReader.Rotation < 0F)
						{
							poReader.Rotation = (360F - poReader.Rotation);
						}
						if (poReader.Rotation >= 270F)
						{
							performanceMatrixData1.FieldOrientation = 270;
							poReader.Rotation -= 270F;
						}
						else if (((double) poReader.Rotation) >= 180D)
						{
							performanceMatrixData1.FieldOrientation = 180;
							poReader.Rotation -= 180F;
						}
						else if (((double) poReader.Rotation) >= 90D)
						{
							performanceMatrixData1.FieldOrientation = 90;
							poReader.Rotation -= 90F;
						}
						else
						{
							performanceMatrixData1.FieldOrientation = ushort.MinValue;
						}
						performanceMatrixData1.XOffset = ((short) (this.CurrentPerformance.XOffset + poReader.XOffset));
						poReader.XOffset = 0;
						performanceMatrixData1.YOffset = ((short) (this.CurrentPerformance.YOffset + poReader.YOffset));
						poReader.YOffset = 0;
						performanceMatrixData1.ZOffset = ((short) (this.CurrentPerformance.ZOffset + poReader.ZOffset));
						poReader.ZOffset = 0;
						performanceMatrixData1.LaserPowerPercent = this.CurrentPerformance.LaserPowerPercent;
						performanceMatrixData1.MarkSpeedPercent = this.CurrentPerformance.MarkSpeedPercent;
						performanceMatrixData1.PeriodPercent = this.CurrentPerformance.PeriodPercent;
						performanceMatrixData1.PulseWidthPercent = this.CurrentPerformance.PulseWidthPercent;
						bool b1 = this.ProcessFixedData (((BaseConfig) performanceMatrixData1), 0);
					}
				}
				catch (Exception exception2)
				{
					exception1 = exception2;
					Logging.Instance.Log (0, string.Format (("DataThread.ExtractOrientationandOffset() - Exception error 0x03d " + exception1.Message), new object[0]));
					Logging.Instance.Log (0, exception1.ToString ());
				}
			}
			
			public Port GetCOMPort (string comPort, DetailedPortSettings portSettings)
			
			{
				if ((comPort == "COM1:") && this.com1Connected)
				{
					return null;
				}
				if ((comPort == "COM2:") && this.com2Connected)
				{
					return null;
				}
				Port port1 = new Port (comPort, portSettings);
				if (port1 == null)
				{
					return null;
				}
				else
				{
					if (port1.PortName == "COM1:")
					{
						this.com1Connected = true;
					}
					if (port1.PortName == "COM2:")
					{
						this.com2Connected = true;
					}
					return port1;
				}
			}
			
			public uint GetOptimumSegmentSize ()
			
			{
				return this.fpgaInterface.SegmentSize;
			}
			
			public bool GetStartMark (int portNum, bool leadingEdge, bool startWhen)
			
			{
				int i1 = this.fpgaInterface.GetRegister (MecFPGARegister.MecReg_CURRENTDIO);
				int i2 = (i1 & ((int) Math.Pow (2D, ((double) (portNum - 1)))));
				bool b1 = false;
				if (startWhen && (i2 > 0))
				{
					b1 = true;
				}
				else if (startWhen && (i2 == 0))
				{
					b1 = false;
				}
				else if ((! startWhen) && (i2 > 0))
				{
					b1 = false;
				}
				else
				{
					b1 |= ((! startWhen) && (i2 == 0));
				}
				if (b1)
				{
					if (leadingEdge)
					{
						return true;
					}
					else
					{
						this.leadingEdgeDetected = true;
						return false;
					}
				}
				if (! this.leadingEdgeDetected)
				{
					return false;
				}
				else
				{
					this.leadingEdgeDetected = false;
					return true;
				}
			}
			
			public bool InitializeFPGA ()
			
			{
				return this.fpgaInterface.Connect ();
			}
			
			private bool LaserMatch (string pstrLaserName)
			
			{
				Exception exception1;
				try
				{
					if (this.CurrentControl == null)
					{
						return false;
					}
					else if ((pstrLaserName == null) || (pstrLaserName.Length == 0))
					{
						return (this.m_oCurrentLaserFileName.CompareTo (this.CurrentControl.LaserFile) == 0);
					}
					else
					{
						return (this.m_oCurrentLaserFileName.CompareTo (pstrLaserName) == 0);
					}
				}
				catch (Exception exception2)
				{
					exception1 = exception2;
					Logging.Instance.Log (0, string.Format (("DataThread.LaserMatch() - Exception error 0x03d " + exception1.Message), new object[0]));
					Logging.Instance.Log (0, exception1.ToString ());
				}
				return false;
			}
			
			private bool LaserMatch ()
			
			{
				return this.LaserMatch (((string) null));
			}
			
			private bool LensMatch ()
			
			{
				return this.LensMatch (((string) null));
			}
			
			private bool LensMatch (string pstrLensName)
			
			{
				Exception exception1;
				try
				{
					if (this.CurrentControl == null)
					{
						return false;
					}
					else if ((pstrLensName == null) || (pstrLensName.Length == 0))
					{
						return (this.m_oCurrentLensFileName.CompareTo (this.CurrentControl.LensFile) == 0);
					}
					else
					{
						return (this.m_oCurrentLensFileName.CompareTo (pstrLensName) == 0);
					}
				}
				catch (Exception exception2)
				{
					exception1 = exception2;
					Logging.Instance.Log (0, string.Format (("DataThread.LensMatch() - Exception error 0x03d " + exception1.Message), new object[0]));
					Logging.Instance.Log (0, exception1.ToString ());
				}
				return false;
			}
			
			public bool LoadDefaultSettings ()
			
			{
				bool b1;
				string string1;
				Exception exception1;
				this.maxBufferSize = ((int) this.fpgaInterface.SegmentSize);
				Logging.Instance.Log (4, "DataThread.SendDefaultSettings() called.");
				try
				{
					b1 = true;
					if (Directory.Exists (CommonSvrUtil.FullConfigPath))
					{
						string1 = Path.GetFileName (AdminSettings.DataSettings.ControlFile);
						if (File.Exists (Path.Combine (CommonSvrUtil.FullConfigPath, string1)))
						{
							b1 = this.ProcessDataFile (string1);
						}
					}
					return b1;
				}
				catch (Exception exception2)
				{
					exception1 = exception2;
					Logging.Instance.Log (0, string.Format (("DataThread.LoadDefaultSettings() - Exception error 0x03d " + exception1.Message), new object[0]));
					Logging.Instance.Log (0, exception1.ToString ());
				}
				return false;
			}
			
			public int LoadFPGAFirmware ()
			
			{
				if (this.fpgaInterface == null)
				{
					return 1;
				}
				else if (! this.fpgaInterface.Connected ())
				{
					return 3;
				}
				else
				{
					Logging.Instance.Log ("Connection to FPGA successful.  Attempting to load firmware.");
					if (this.fpgaInterface.LoadFirmware ())
					{
						Logging.Instance.Log ("Loading firmware successful.  Attempting to reset.");
						if (this.fpgaInterface.Reset () == ResetType.Failed)
						{
							Logging.Instance.Log ("Reset failed.");
							return 2;
						}
						else
						{
							Logging.Instance.Log ("Reset successful.");
							return 0;
						}
					}
					Logging.Instance.Log ("Loading firmware failed.  Attempting to reset.");
					return 1;
				}
			}
			
			private UserConfigReader ParseTransformLensValues (int piTableNumber)
			
			{
				Exception exception1;
				UserConfigReader userConfigReader1 = new UserConfigReader ();
				try
				{
					if (this.CurrentLens != null)
					{
						if (piTableNumber == 1)
						{
							userConfigReader1.XOffset += this.CurrentLens.Table1XOffset;
							userConfigReader1.YOffset += this.CurrentLens.Table1YOffset;
							userConfigReader1.XGain = this.CurrentLens.Table1XGain;
							userConfigReader1.YGain = this.CurrentLens.Table1YGain;
							userConfigReader1.Rotation += this.CurrentLens.Table1Rotation;
						}
						else if (piTableNumber == 2)
						{
							userConfigReader1.XOffset += this.CurrentLens.Table2XOffset;
							userConfigReader1.YOffset += this.CurrentLens.Table2YOffset;
							userConfigReader1.XGain = this.CurrentLens.Table2XGain;
							userConfigReader1.YGain = this.CurrentLens.Table2YGain;
							userConfigReader1.Rotation += this.CurrentLens.Table2Rotation;
						}
					}
					if (this.CurrentUser != null)
					{
						userConfigReader1 += this.CurrentUser;
					}
				}
				catch (Exception exception2)
				{
					exception1 = exception2;
					Logging.Instance.Log (0, string.Format (("DataThread.CorrTransformValues() - Exception error 0x03d " + exception1.Message), new object[0]));
					Logging.Instance.Log (0, exception1.ToString ());
				}
				this.ExtractOrientationandOffset (userConfigReader1, piTableNumber);
				return userConfigReader1;
			}
			
			private void ProcessCorrectData (CorrTableReader poCorrect, int piTableId, ref byte[] pbyteBuf, out int piBufSize, ref int piIndexOpcode, out int piTotalOpcodes)
			
			{
				byte[] byteArray1;
				int i2;
				int i3;
				int i4;
				Exception exception1;
				int i5;
				Logging.Instance.Log (4, "DataThread.ProcessCorrectData() called.");
				piTotalOpcodes = (1 + (poCorrect.TotalPoints * 3));
				int i1 = 0;
				piBufSize = 0;
				try
				{
					byteArray1 = ((byte[]) null);
					if (i1 >= piIndexOpcode)
					{
						if ((piBufSize + 4) > pbyteBuf.Length)
						{
							piIndexOpcode = (i1 - 1);
							return;
						}
						else
						{
							byteArray1 = BitConverter.GetBytes (4370);
							Array.Copy (((Array) byteArray1), 0, ((Array) pbyteBuf), piBufSize, byteArray1.Length);
							piBufSize += byteArray1.Length;
							byteArray1 = BitConverter.GetBytes (((short) piTableId));
							Array.Copy (((Array) byteArray1), 0, ((Array) pbyteBuf), piBufSize, byteArray1.Length);
							piBufSize += byteArray1.Length;
						}
					}
					i1++;
					i2 = 0;
					
				L_01F7:
					
					{
					}
					if (i2 < 3)
					{
						for (i3 = 0; (i3 < poCorrect.TotalPoints); i3++)
						{
							if (i1 >= piIndexOpcode)
							{
								if ((piBufSize + 8) > pbyteBuf.Length)
								{
									piIndexOpcode = (i1 - 1);
									return;
								}
								byteArray1 = BitConverter.GetBytes (20753);
								Array.Copy (((Array) byteArray1), 0, ((Array) pbyteBuf), piBufSize, byteArray1.Length);
								piBufSize += byteArray1.Length;
								byteArray1 = BitConverter.GetBytes (((short) (i3 + (poCorrect.TotalPoints * i2))));
								Array.Copy (((Array) byteArray1), 0, ((Array) pbyteBuf), piBufSize, byteArray1.Length);
								piBufSize += byteArray1.Length;
								i4 = 0;
								i5 = i2;
								switch (i5)
								{
									case 0:
									
									{
											i4 = Convert.ToInt32 (Math.Max (Math.Min (((Point3D) poCorrect[i3]).X, 2147483647D), -2147483648D));
											break;
									}
									case 1:
									
									{
											i4 = Convert.ToInt32 (Math.Max (Math.Min (((Point3D) poCorrect[i3]).Y, 2147483647D), -2147483648D));
											break;
									}
									case 2:
									
									{
											i4 = Convert.ToInt32 (Math.Max (Math.Min (((Point3D) poCorrect[i3]).Z, 2147483647D), -2147483648D));
											break;
									}
								}
								byteArray1 = BitConverter.GetBytes (i4);
								Array.Copy (((Array) byteArray1), 0, ((Array) pbyteBuf), piBufSize, byteArray1.Length);
								piBufSize += byteArray1.Length;
							}
							i1++;
						}
						i2++;
						goto L_01F7;
					}
					else
					{
						piIndexOpcode = i1;
					}
				}
				catch (Exception exception2)
				{
					exception1 = exception2;
					Logging.Instance.Log (0, string.Format (("DataThread.ProcessCorrectData() - Exception error 0x03d " + exception1.Message), new object[0]));
					Logging.Instance.Log (0, exception1.ToString ());
				}
			}
			
			public bool ProcessDataFile (string pstrFile)
			
			{
				string string1;
				BaseConfig baseConfig1;
				bool b1;
				Exception exception1;
				Logging.Instance.Log (4, "DataThread.ProcessDataFile(string) called.");
				try
				{
					string1 = Path.Combine (CommonSvrUtil.FullConfigPath, pstrFile);
					if (Path.GetExtension (string1).Length == 0)
					{
						string1 = (string1 + ".xml");
					}
					baseConfig1 = IdentifyReader.IdentifyConfigurationFile (string1);
					if (baseConfig1 != null)
					{
						if ((baseConfig1 is CorrTableReader) && (this.m_oCurrentCorrectionInfo != null))
						{
							b1 = this.ProcessFixedDataFile (baseConfig1, string1, ((int) this.m_oCurrentCorrectionInfo.ApplyTable));
						}
						else
						{
							b1 = this.ProcessFixedDataFile (baseConfig1, string1, 0);
						}
						LECHAL.Instance.bFixDataProcessed = true;
						return b1;
					}
				}
				catch (Exception exception2)
				{
					exception1 = exception2;
					Logging.Instance.Log (0, string.Format (("DataThread.ProcessDataFile() - Exception error 0x03d " + exception1.Message), new object[0]));
					Logging.Instance.Log (0, exception1.ToString ());
				}
				return false;
			}
			
			private bool ProcessFixedData (BaseConfig poConfig, int piParameter)
			
			{
				bool b1;
				byte[] byteArray1;
				int i1;
				int i2;
				int i3;
				ControlConfigReader controlConfigReader1;
				Exception exception1;
				Logging.Instance.Log (4, "DataThread.ProcessData() called.");
				try
				{
					byteArray1 = new byte[this.maxBufferSize];
					i1 = -1;
					i2 = 0;
					i3 = 0;
					while (true)
					{
						i1++;
						if (poConfig is ControlConfigReader)
						{
							controlConfigReader1 = ((ControlConfigReader) poConfig);
							this.fpgaInterface.SetInterlockProperties (controlConfigReader1.InterlockConfig);
							EngineUtil.ProcessControlData (((ControlConfigReader) poConfig), ref byteArray1, out i2, ref i1, out i3);
						}
						else if (poConfig is LaserConfigReader)
						{
							EngineUtil.ProcessLaserData (((LaserConfigReader) poConfig), ref byteArray1, out i2, ref i1, out i3);
						}
						else if (poConfig is CorrTableReader)
						{
							this.ProcessCorrectData (((CorrTableReader) poConfig), piParameter, ref byteArray1, out i2, ref i1, out i3);
						}
						else if (! (poConfig is PerformanceMatrixData))
						{
							return false;
						}
						else
						{
							EngineUtil.ProcessPerformanceData (((PerformanceMatrixData) poConfig), ref byteArray1, out i2, ref i1, out i3);
						}
						if (AdminSettings.DataSettings.EnableStreamToFile)
						{
							if (this.m_oWriter == null)
							{
								this.m_oWriter = new BinaryWriter (((Stream) File.Open (Path.Combine (CommonSvrUtil.FullConfigPath, ("Fixed_" + AdminSettings.DataSettings.StreamFile)), FileMode.Create)));
							}
							if (this.m_oWriter != null)
							{
								this.m_oWriter.Write (byteArray1, 0, i2);
							}
						}
						b1 = this.fpgaInterface.SendData (byteArray1, i2);
						if (! b1)
						{
							Logging.Instance.Log (("DataThread.ProcessData() - " + this.fpgaInterface.MessageLog));
						}
						else
						{
							Logging.Instance.Log ("DataThread.ProcessData() - Wrote {0} bytes.", i2);
						}
						if ((i1 >= i3) || (! b1))
						{
							return b1;
						}
					}
				}
				catch (Exception exception2)
				{
					exception1 = exception2;
					Logging.Instance.Log (0, string.Format (("DataThread.ProcessData() - Exception error 0x03d " + exception1.Message), new object[0]));
					Logging.Instance.Log (0, exception1.ToString ());
				}
				return false;
			}
			
			private bool ProcessFixedDataFile (BaseConfig poConfig, string pstrPathFile, int piSelection)
			
			{
				string string1;
				UserConfigReader userConfigReader1;
				CorrTableReader corrTableReader1;
				UserConfigReader userConfigReader2;
				CorrTableReader corrTableReader2;
				bool b1;
				bool b2;
				PerformanceMatrixData performanceMatrixData1;
				Exception exception1;
				bool b3;
				Logging.Instance.Log (4, "DataThread.ProcessDataFile(BaseConfig) called.");
				try
				{
					string1 = Path.GetFileNameWithoutExtension (pstrPathFile);
					if (poConfig is ControlConfigReader)
					{
						Logging.Instance.Log (4, "DataThread.ProcessDataFile() - detected Controller.  Update.");
						if (this.fpgaInterface.Abort)
						{
							return false;
						}
						else if (! this.ProcessFixedData (poConfig, 0))
						{
							return false;
						}
						else
						{
							this.CurrentControl = (poConfig as ControlConfigReader);
							if (this.fpgaInterface.Abort)
							{
								return false;
							}
							else
							{
								if (! this.LaserMatch (this.CurrentControl.LaserFile))
								{
									this.CurrentLaser = ((LaserConfigReader) null);
									bool b4 = this.ProcessFixedDataFile (((BaseConfig) this.CurrentLaser), this.CurrentControl.LaserFile, 0);
								}
								if (this.fpgaInterface.Abort)
								{
									return false;
								}
								else
								{
									if (! this.Corr2Match (this.CurrentControl.CorrFile2))
									{
										this.CurrentCorr2 = ((CorrTableReader) null);
										if (this.CurrentCorr2 != null)
										{
											bool b5 = this.ProcessFixedDataFile (((BaseConfig) this.CurrentCorr2), this.CurrentControl.CorrFile2, 2);
										}
									}
									if (this.fpgaInterface.Abort)
									{
										return false;
									}
									else if (! this.Corr1Match (this.CurrentControl.CorrFile1))
									{
										this.CurrentCorr1 = ((CorrTableReader) null);
										if (this.CurrentCorr1 != null)
										{
											bool b6 = this.ProcessFixedDataFile (((BaseConfig) this.CurrentCorr1), this.CurrentControl.CorrFile1, 1);
										}
									}
								}
							}
						}
					}
					else if (! (poConfig is CorrTableReader))
					{
						if (! (poConfig is LensConfigReader))
						{
							if (! (poConfig is UserConfigReader))
							{
								if (! (poConfig is LaserConfigReader))
								{
									if (poConfig is PerformanceMatrixData)
									{
										Logging.Instance.Log (4, "DataThread.ProcessDataFile() - detected PerformanceMatrix needs updating.");
										this.CurrentPerformance = (poConfig as PerformanceMatrixData);
										performanceMatrixData1 = this.CombineLensTable1Values ();
										bool b11 = this.ProcessFixedData (((BaseConfig) performanceMatrixData1), 0);
										Logging.Instance.Log (4, "LECHAL.ProcessDataFile() - Successfully updated PerformanceMatrix");
									}
								}
								else if (this.LaserMatch (string1))
								{
									Logging.Instance.Log (4, "DataThread.ProcessDataFile() - detected Laser needs updating.");
									this.CurrentLaser = (poConfig as LaserConfigReader);
									this.CurrentLaserFileName = string1;
									if (! this.ProcessFixedData (poConfig, 0))
									{
										return false;
									}
									else
									{
										Logging.Instance.Log (4, "DataThread.ProcessDataFile() - Successfully updated Laser");
									}
								}
							}
							else if (this.UserMatch (string1) && (! ((UserConfigReader) poConfig).Equals (this.CurrentUser)))
							{
								Logging.Instance.Log (4, "DataThread.ProcessDataFile() - detected User needs updating.");
								this.CurrentUser = (poConfig as UserConfigReader);
								this.CurrentUserFileName = string1;
								bool b9 = this.ProcessFixedDataFile (((BaseConfig) this.CurrentCorr2), this.CurrentControl.CorrFile2, 2);
								bool b10 = this.ProcessFixedDataFile (((BaseConfig) this.CurrentCorr1), this.CurrentControl.CorrFile1, 1);
								Logging.Instance.Log (4, "DataThread.ProcessDataFile() - Successfully updated User");
							}
						}
						else if (this.LensMatch (string1) && (! ((LensConfigReader) poConfig).Equals (this.CurrentLens)))
						{
							Logging.Instance.Log (4, "DataThread.ProcessDataFile() - detected Lens needs updating.");
							b1 = (! ((LensConfigReader) poConfig).EqualsTable1 (this.CurrentLens));
							b2 = (! ((LensConfigReader) poConfig).EqualsTable2 (this.CurrentLens));
							this.CurrentLens = (poConfig as LensConfigReader);
							this.CurrentLensFileName = string1;
							if (b2)
							{
								bool b7 = this.ProcessFixedDataFile (((BaseConfig) this.CurrentCorr2), this.CurrentControl.CorrFile2, 2);
							}
							if (b1)
							{
								bool b8 = this.ProcessFixedDataFile (((BaseConfig) this.CurrentCorr1), this.CurrentControl.CorrFile1, 1);
							}
							Logging.Instance.Log (4, "DataThread.ProcessDataFile() - Successfully updated Lens");
						}
					}
					else
					{
						if (this.Corr2Match (string1) && ((piSelection == 0) || ((piSelection & 2) > 0)))
						{
							Logging.Instance.Log (4, "DataThread.ProcessDataFile() - detected CorrTable2 needs updating.");
							this.CurrentCorr2 = (poConfig as CorrTableReader);
							this.CurrentCorr2FileName = string1;
							userConfigReader1 = this.ParseTransformLensValues (2);
							if (this.fpgaInterface.Abort)
							{
								return false;
							}
							else
							{
								if ((this.CurrentCorr2Settings == null) || (! this.CurrentCorr2Settings.Equals (userConfigReader1)))
								{
									corrTableReader1 = ((CorrTableReader) null);
									if ((this.m_oCurrentCorrectionInfo == null) || ((this.m_oCurrentCorrectionInfo.ApplyTable & LanmarkControls.CommonLib.Protocol.AtUpdateCorrInfo.TableType.Correction2) >  ((LanmarkControls.CommonLib.Protocol.AtUpdateCorrInfo.TableType) 0)))
									{
										corrTableReader1 = EngineUtil.TransformCorrTable ((poConfig as CorrTableReader), userConfigReader1, this.m_oCurrentCorrectionInfo);
									}
									else
									{
										Logging.Instance.Log (4, "DataThread.ProcessDataFile() - Transforms not applied to CorrTable2.");
										corrTableReader1 = (poConfig as CorrTableReader);
									}
									if (this.fpgaInterface.Abort)
									{
										return false;
									}
									else if (! this.ProcessFixedData (((BaseConfig) corrTableReader1), 1))
									{
										return false;
									}
									else
									{
										this.CurrentCorr2Settings = userConfigReader1;
									}
								}
								Logging.Instance.Log (4, "DataThread.ProcessDataFile() - Successfully updated CorrTable2.");
							}
						}
						if (this.Corr1Match (string1) && ((piSelection == 0) || ((piSelection & 1) > 0)))
						{
							Logging.Instance.Log (4, "DataThread.ProcessDataFile() - detected CorrTable1 needs updating.");
							this.CurrentCorr1 = (poConfig as CorrTableReader);
							this.CurrentCorr1FileName = string1;
							userConfigReader2 = this.ParseTransformLensValues (1);
							if (this.fpgaInterface.Abort)
							{
								return false;
							}
							else
							{
								if ((this.CurrentCorr1Settings == null) || (! this.CurrentCorr1Settings.Equals (userConfigReader2)))
								{
									corrTableReader2 = ((CorrTableReader) null);
									if ((this.m_oCurrentCorrectionInfo == null) || ((this.m_oCurrentCorrectionInfo.ApplyTable & LanmarkControls.CommonLib.Protocol.AtUpdateCorrInfo.TableType.Correction1) >  ((LanmarkControls.CommonLib.Protocol.AtUpdateCorrInfo.TableType) 0)))
									{
										corrTableReader2 = EngineUtil.TransformCorrTable ((poConfig as CorrTableReader), userConfigReader2, this.m_oCurrentCorrectionInfo);
									}
									else
									{
										Logging.Instance.Log (4, "DataThread.ProcessDataFile() - Transforms not applied to CorrTable1.");
										corrTableReader2 = (poConfig as CorrTableReader);
									}
									if (this.fpgaInterface.Abort)
									{
										return false;
									}
									else if (! this.ProcessFixedData (((BaseConfig) corrTableReader2), 0))
									{
										return false;
									}
									else
									{
										this.CurrentCorr1Settings = userConfigReader2;
									}
								}
								Logging.Instance.Log (4, "DataThread.ProcessDataFile() - Successfully updated CorrTable1.");
							}
						}
					}
					if (this.fpgaInterface.Abort)
					{
						return false;
					}
					else
					{
						b3 = true;
					}
				}
				catch (Exception exception2)
				{
					exception1 = exception2;
					Logging.Instance.Log (0, string.Format (("DataThread.ProcessDataFile() - Exception error 0x03d " + exception1.Message), new object[0]));
					Logging.Instance.Log (0, exception1.ToString ());
					b3 = false;
				}
				return b3;
			}
			
			public bool ProcessInformation (string pstrInfo)
			
			{
				Exception exception1;
				Logging.Instance.Log (4, "DataThread.ProcessInformation() called.");
				try
				{
					this.m_oCurrentCorrectionInfo = new AtUpdateCorrInfo ();
					this.m_oCurrentCorrectionInfo.FromXML (pstrInfo);
					if (this.m_oCurrentCorrectionInfo.ApplyTransforms ==  ((LanmarkControls.CommonLib.Protocol.AtUpdateCorrInfo.TransformType) 7))
					{
						this.m_oCurrentCorrectionInfo = ((AtUpdateCorrInfo) null);
					}
					return true;
				}
				catch (Exception exception2)
				{
					exception1 = exception2;
					Logging.Instance.Log (0, string.Format (("DataThread.ProcessInformation() - Exception error 0x03d " + exception1.Message), new object[0]));
					Logging.Instance.Log (0, exception1.ToString ());
				}
				return false;
			}
			
			public void ResetBoard ()
			
			{
				PLI pLI1 = new PLI ();
				bool b1 = pLI1.Connect ();
				pLI1.ResetBoard ();
			}
			
			public ResetType ResetFPGA ()
			
			{
				return this.fpgaInterface.Reset ();
			}
			
			public bool ResumeJob ()
			
			{
				return this.fpgaInterface.ResumeJob ();
			}
			
			public void SavePerformanceMatrixToFile ()
			
			{
				string string1 = Path.Combine (CommonSvrUtil.FullConfigPath, ("LEC" + this.CurrentPerformance.DefaultFileName));
				if (File.Exists (string1))
				{
					File.Delete (string1);
				}
				bool b1 = XmlUtil.CreateXML (string1, this.CurrentPerformance.ToXML (uint.MinValue));
			}
			
			public bool SendFPGAStreamData (byte[] pbyteData, int piDataSize)
			
			{
				return this.fpgaInterface.SendData (pbyteData, piDataSize);
			}
			
			public bool SendFPGAStreamData (byte[] dataBuffer)
			
			{
				return this.fpgaInterface.SendData (dataBuffer);
			}
			
			public void SetAlignMatrix (double A, double B, double C, double D, double Xo, double Yo)
			
			{
				this.AlignMatrix.SetMatrix (A, B, C, D, Xo, Yo);
				this.UpdateHardwareMatrix ();
			}
			
			public bool SetCachedInterlockSetting ()
			
			{
				this.fpgaInterface.SetCachedInterlockSetting ();
				return true;
			}
			
			public bool SetInterlockEnable (byte bConfig)
			
			{
				this.fpgaInterface.SetInterlockEnable (bConfig);
				return true;
			}
			
			public void SetObjectMatrix (double A, double B, double C, double D, double Xo, double Yo)
			
			{
				this.ObjectMatrix.SetMatrix (A, B, C, D, Xo, Yo);
				this.UpdateHardwareMatrix ();
			}
			
			public void SetStepRepeatMatrix (double A, double B, double C, double D, double Xo, double Yo)
			
			{
				this.StepRepeatMatrix.SetMatrix (A, B, C, D, Xo, Yo);
				this.UpdateHardwareMatrix ();
			}
			
			public void setUSBPower (bool state)
			
			{
				PLI pLI1 = new PLI ();
				bool b1 = pLI1.Connect ();
				pLI1.setUSBPower (state);
				bool b2 = pLI1.Disconnect ();
			}
			
			public void StartCommandProcessing (bool startFlag)
			
			{
				bool b1 = this.fpgaInterface.StartCommandProcessing (startFlag);
			}
			
			public bool SuspendJob ()
			
			{
				return this.fpgaInterface.SuspendJob ();
			}
			
			public void UpdateHardwareMatrix ()
			
			{
				Matrix matrix1 = new Matrix ();
				matrix1 = (this.ObjectMatrix * this.AlignMatrix);
				this.HardwareMatrix = (matrix1 * this.StepRepeatMatrix);
			}
			
			public void UpdatePerformanceMatrix ()
			
			{
				bool b1 = this.ProcessFixedData (((BaseConfig) this.CurrentPerformance), 0);
			}
			
			private bool UserMatch (string pstrUserName)
			
			{
				Exception exception1;
				try
				{
					if (this.CurrentControl == null)
					{
						return false;
					}
					else if ((pstrUserName == null) || (pstrUserName.Length == 0))
					{
						return (this.m_oCurrentUserFileName.CompareTo (this.CurrentControl.UserFile) == 0);
					}
					else
					{
						return (this.m_oCurrentUserFileName.CompareTo (pstrUserName) == 0);
					}
				}
				catch (Exception exception2)
				{
					exception1 = exception2;
					Logging.Instance.Log (0, string.Format (("DataThread.UserMatch() - Exception error 0x03d " + exception1.Message), new object[0]));
					Logging.Instance.Log (0, exception1.ToString ());
				}
				return false;
			}
			
			private bool UserMatch ()
			
			{
				return this.UserMatch (((string) null));
			}
			
		#endregion
	}
	
}

